@@ -27,10 +27,7 @@ have_func('atk_text_get_bounded_ranges')
 have_func('atk_role_get_localized_name')
 have_func('atk_text_clip_type_get_type')
 
-unless /cygwin/ =~ RUBY_PLATFORM
-  #FIXME
-  have_func('atk_text_free_ranges')
-end
+have_func('atk_text_free_ranges')
 
 add_depend_package("glib2", "glib/src", TOPDIR)
 add_distcleanfile("rbatkinits.c")
