@@ -1,9 +1,9 @@
 =begin
   top-level extconf.rb for Ruby-GNOME2
 
-  $Id: extconf.rb,v 1.11 2004/08/15 15:06:39 mutoh Exp $
+  $Id: extconf.rb,v 1.13 2005/02/24 13:02:45 ktou Exp $
 
-  Copyright (C) 2003,2004 Ruby-GNOME2 Project Team
+  Copyright (C) 2003-2005 Ruby-GNOME2 Project Team
 =end
 
 require 'mkmf'
@@ -14,9 +14,17 @@ priorlibs = ["glib", "gdkpixbuf", "pango", "atk", "gtk"]
 #
 # detect sub-directories
 #
-$ruby = File.join(Config::CONFIG['bindir'], Config::CONFIG['RUBY_INSTALL_NAME'])
+$ruby = File.join(Config::CONFIG['bindir'], Config::CONFIG['RUBY_INSTALL_NAME'] + Config::CONFIG['EXEEXT'])
 $ruby = arg_config("--ruby", $ruby)
 
+rm = "rm -f "
+if /mswin32/ =~ RUBY_PLATFORM
+  rm = "del " 
+  $ruby.gsub!(/\//, '\\')
+end
+
+
+
 $srcdir = File.dirname(__FILE__)
 $topsrcdir = $configure_args["--topsrcdir"] ||= $srcdir
 $topdir = $configure_args["--topdir"] ||= Dir.pwd
@@ -68,25 +76,27 @@ File.open("Makefile", "w") do |makefile|
 TOPSRCDIR = #{$topsrcdir}
 SUBDIRS = #{targets.join(' ')}
 COMMAND = #{$ruby} #{$topsrcdir}/exec_make.rb #{$strict}
+RM = #{rm}
 
 all:
-	$(COMMAND) '$(SUBDIRS)' $(MAKE) all;
+	$(COMMAND) '$(SUBDIRS)' $(MAKE) all
 
 install:
-	$(COMMAND) '$(SUBDIRS)' $(MAKE) install;
+	$(COMMAND) '$(SUBDIRS)' $(MAKE) install
 
 site-install:
-	$(COMMAND) '$(SUBDIRS)' $(MAKE) site-install;
+	$(COMMAND) '$(SUBDIRS)' $(MAKE) site-install
 
 clean:
-	$(COMMAND) '$(SUBDIRS)' $(MAKE) clean;
+	$(COMMAND) '$(SUBDIRS)' $(MAKE) clean
 
 distclean:
-	$(COMMAND) '$(SUBDIRS)' $(MAKE) distclean;
-	rm -f Makefile mkmf.log
+	$(COMMAND) '$(SUBDIRS)' $(MAKE) distclean
+	$(RM) Makefile mkmf.log
 ")
 end
 
 puts "-----"
 puts "Done."
 
+$makefile_created = true
