@@ -3,8 +3,8 @@
 
   rbgdk-pixbuf.c -
 
-  $Author: mutoh $
-  $Date: 2005/07/22 17:46:34 $
+  $Author: ggc $
+  $Date: 2005/09/28 20:37:27 $
 
   Copyright (C) 2002-2004 Masao Mutoh
   Copyright (C) 2000 Yasushi Shoji
@@ -59,10 +59,18 @@ static VALUE
 get_pixels(self)
     VALUE self;
 {
-    guchar* pixels = gdk_pixbuf_get_pixels(_SELF(self));
-    return rb_str_new((const char*)pixels,
-                      gdk_pixbuf_get_height(_SELF(self)) * 
-                      gdk_pixbuf_get_rowstride(_SELF(self)));
+    GdkPixbuf *pixbuf = _SELF(self);
+    int size, height, width, rowstride, n_channels, bits_per_sample;
+
+    height = gdk_pixbuf_get_height(pixbuf);
+    width = gdk_pixbuf_get_width(pixbuf);
+    rowstride = gdk_pixbuf_get_rowstride(pixbuf);
+    n_channels = gdk_pixbuf_get_n_channels(pixbuf);
+    bits_per_sample = gdk_pixbuf_get_bits_per_sample(pixbuf);
+    
+    size = ((height - 1) * rowstride +
+            width * ((n_channels * bits_per_sample + 7) / 8));
+    return rb_str_new((const char*)gdk_pixbuf_get_pixels(pixbuf), size);
 }
 
 static VALUE
@@ -124,6 +132,8 @@ initialize(argc, argv, self)
                                            NUM2INT(arg7), NULL, NULL);
             if (buf == NULL) NOMEM_ERROR(&error);
         }
+        // Save a reference to the string because the pixbuf doesn't copy it.
+        G_RELATIVE(self, arg1);
     } else if (argc == 5){
         if (rb_obj_is_kind_of(arg1, GTYPE2CLASS(GDK_TYPE_PIXBUF))){
             buf = gdk_pixbuf_new_subpixbuf(_SELF(arg1), 
@@ -675,6 +685,9 @@ Init_gdk_pixbuf2()
 #endif
 
     Init_gdk_pixbuf_animation(mGdk);
+#if RBGDK_PIXBUF_CHECK_VERSION(2,8,0)
+    Init_gdk_pixbuf_simpleanim(mGdk);
+#endif
     Init_gdk_pixdata(mGdk);
     Init_gdk_pixbuf_loader(mGdk);
     Init_gdk_pixbuf_format(mGdk);
