@@ -1,11 +1,11 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 =begin
   xpm.rb - Ruby/GdkPixbuf sample script.
 
-  Copyright (c) 2002,2003 Ruby-GNOME2 Project Team
+  Copyright (c) 2002-2006 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: xpm.rb,v 1.3 2003/01/17 19:20:47 mutoh Exp $
+  $Id: xpm.rb,v 1.5 2006/06/17 14:38:08 mutoh Exp $
 =end
 
 require 'gtk2'
@@ -26,8 +26,6 @@ r_xpm = [
       "+..+++...+",
       "+..++++..+"]     
 
-Gtk.init
-
 w = Gtk::Window.new
 w.signal_connect('delete-event') do
   Gtk.main_quit
