@@ -37,7 +37,7 @@ end
 include_path = nil
 if ENV['GTK_BASEPATH'] and /cygwin/ !~ RUBY_PLATFORM
   include_path = (ENV['GTK_BASEPATH'] + "\\INCLUDE").gsub("\\", "/")
-  $hdrdir = include_path
+#  $hdrdir += " -I#{include_path} "
   $CFLAGS += " -I#{include_path} " 
 end
 
