@@ -4,10 +4,10 @@
   rbgobj_enums.c -
 
   $Author: mutoh $
-  $Date: 2005/01/29 11:41:17 $
+  $Date: 2006/05/14 10:33:18 $
   created at: Sat Jul 27 16:56:01 JST 2002
 
-  Copyright (C) 2004 Ruby-GNOME2 Project Team
+  Copyright (C) 2004-2006  Ruby-GNOME2 Project Team
   Copyright (C) 2002,2003  Masahiro Sakai
 **********************************************************************/
 
@@ -138,6 +138,7 @@ rbgobj_flags_add_constants(VALUE mod, GType flags_type,
             const char* name = value->value_name + prefix_len;
             rbgobj_define_const(mod, name,
                                 rbgobj_make_flags(value->value, flags_type));
+
         }
     }
 
@@ -219,11 +220,13 @@ rbgobj_init_enum_class(VALUE klass)
         gchar* nick = g_strdup(entry->value_nick);
         gchar* p;
 
-        for (p = nick; *p; p++) {
-            if (*p == '-')
-                *p = '_';
-            else
-                *p = toupper(*p);
+        if (nick) {
+            for (p = nick; *p; p++) {
+              if (*p == '-' || *p == ' ')
+                  *p = '_';
+              else
+                  *p = toupper(*p);
+            }
         }
 
 #if 0
@@ -237,7 +240,9 @@ rbgobj_init_enum_class(VALUE klass)
 #else
         {
             VALUE value = rbgobj_make_enum(entry->value, CLASS2GTYPE(klass));
-            rbgobj_define_const(klass, nick, value);
+            if (nick) {
+              rbgobj_define_const(klass, nick, value);
+            }
         }
 #endif
 
@@ -492,8 +497,10 @@ rbgobj_init_flags_class(VALUE klass)
         }
 
         for (p = nick; *p; p++)
-            if (*p == '-')
+            if (*p == '-' || *p == ' ')
                 *p = '_';
+            else
+                *p = tolower(*p);
 
         g_string_append_printf(
             source,
