@@ -3,8 +3,8 @@
 
   rbgobj_object.c -
 
-  $Author: mutoh $
-  $Date: 2005/07/22 17:32:18 $
+  $Author: ssimons $
+  $Date: 2006/06/09 21:30:26 $
 
   Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
   Copyright (C) 2002-2003  Masahiro Sakai
@@ -52,6 +52,35 @@ is_gtkobject(gobj)
     return gtype_gtkobject && g_type_is_a(G_OBJECT_TYPE(gobj), gtype_gtkobject);
 }
 
+static void
+gobj_mark(gpointer ptr)
+{
+    GObject* gobj = ptr;
+    guint n_properties;
+    GParamSpec** properties;
+    GValue gval = {0,};
+    int i;
+
+    properties = g_object_class_list_properties(G_OBJECT_GET_CLASS(gobj), &n_properties);
+
+    for (i = 0; i < n_properties; i++) {
+        GParamSpec* pspec = properties[i];
+        GType value_type = G_PARAM_SPEC_VALUE_TYPE(pspec);
+        if (G_TYPE_FUNDAMENTAL(value_type) != G_TYPE_OBJECT) continue;
+        if (!(pspec->flags & G_PARAM_READABLE)) continue;
+        /* FIXME: exclude types that doesn't have identity. */
+
+        {
+            g_value_init(&gval, value_type);
+            g_object_get_property(gobj, pspec->name, &gval);
+            rbgobj_gc_mark_gvalue(&gval);
+            g_value_unset(&gval);
+        }
+    }
+
+    g_free(properties);
+}
+
 static VALUE
 gobj_s_gobject_new(argc, argv, self)
     int argc;
@@ -261,6 +290,8 @@ gobj_set_property(self, prop_name, val)
         g_object_set_property(RVAL2GOBJ(self), name, &gval);
         g_value_unset(&gval);
 
+        G_CHILD_SET(self, rb_intern(name), val);
+
         return self;
     }
 }
@@ -302,8 +333,12 @@ gobj_get_property(self, prop_name)
 
         g_value_init(&gval, G_PARAM_SPEC_VALUE_TYPE(pspec));
         g_object_get_property(RVAL2GOBJ(self), name, &gval);
+
         ret = getter ? getter(&gval) : GVAL2RVAL(&gval);
         g_value_unset(&gval);
+
+        G_CHILD_SET(self, rb_intern(name), ret);
+
         return ret;
     }
 }
@@ -415,24 +450,6 @@ gobj_ref_count(self)
     return INT2NUM(gobj ? gobj->ref_count : 0);
 }
 
-static VALUE
-gobj_smethod_added(self, id)
-    VALUE self, id;
-{
-    GObject *obj = RVAL2GOBJ(self);
-    const char* name = rb_id2name(SYM2ID(id));
-    guint signal_id = g_signal_lookup(name, G_OBJECT_TYPE(obj));
-    
-    if (signal_id) {
-        VALUE method = rb_funcall(self, rb_intern("method"), 1, id);
-        GClosure* closure = g_rclosure_new(method, Qnil,
-                                           rbgobj_get_signal_func(signal_id));
-        g_signal_connect_closure(obj, name, closure, FALSE);
-    }
-
-    return Qnil;
-}
-
 /**********************************************************************/
 
 static VALUE proc_mod_eval;
@@ -601,7 +618,7 @@ Init_gobject_subclass()
 void 
 Init_gobject_gobject()
 {
-    VALUE cGObject = G_DEF_CLASS(G_TYPE_OBJECT, "Object", mGLib);
+    VALUE cGObject = G_DEF_CLASS2(G_TYPE_OBJECT, "Object", mGLib, gobj_mark, NULL);
 
 #ifndef HAVE_RB_DEFINE_ALLOC_FUNC
     rb_define_singleton_method(cGObject, "allocate", &gobj_s_allocate, 0);
@@ -627,8 +644,6 @@ Init_gobject_gobject()
     rb_define_method(cGObject, "ref_count", gobj_ref_count, 0); /* for debugging */
     rb_define_method(cGObject, "inspect", gobj_inspect, 0);
 
-    rb_define_method(cGObject, "singleton_method_added", gobj_smethod_added, 1);
-
     eNoPropertyError = rb_define_class_under(mGLib, "NoPropertyError",
                                              rb_eNameError);
 
