@@ -3,8 +3,8 @@
 
   rbgobj_signal.c -
 
-  $Author: mutoh $
-  $Date: 2005/09/15 06:25:30 $
+  $Author: sakai $
+  $Date: 2006/05/29 05:41:37 $
   created at: Sat Jul 27 16:56:01 JST 2002
 
   Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
@@ -46,7 +46,7 @@ rbgobj_get_signal_func(guint signal_id)
 
 /**********************************************************************/
 
-VALUE eNoSignalError;
+static VALUE eNoSignalError;
 
 // FIXME: use rb_protect
 static gboolean
@@ -114,6 +114,7 @@ gobj_s_signal_new(int argc, VALUE* argv, VALUE self)
         proc = rb_funcall(factory, rb_intern("call"), 2, self, ID2SYM(method_id));
 
         class_closure = g_rclosure_new(proc, Qnil, NULL);
+        g_rclosure_attach(class_closure, self);
     }
 
     if (NIL_P(params)) {
@@ -146,7 +147,7 @@ gobj_s_signal_new(int argc, VALUE* argv, VALUE self)
     return rbgobj_signal_wrap(sig);
 }
 
-void
+static void
 _signal_list(VALUE result, GType gtype)
 {
     guint n_ids, i;
@@ -232,7 +233,8 @@ gobj_sig_has_handler_pending(argc, argv, self)
 }
 
 static VALUE
-gobj_sig_connect(argc, argv, self)
+gobj_sig_connect_impl(after, argc, argv, self)
+    gboolean after;
     int argc;
     VALUE *argv;
     VALUE self;
@@ -258,44 +260,30 @@ gobj_sig_connect(argc, argv, self)
         rb_raise(eNoSignalError, "no such signal: %s", sig_name);
 
     func = G_BLOCK_PROC();
-    G_RELATIVE(self, func);
     rclosure = g_rclosure_new(func, rest, 
                               rbgobj_get_signal_func(signal_id));
-    i = g_signal_connect_closure_by_id(RVAL2GOBJ(self), signal_id, detail, rclosure, FALSE);
+    g_rclosure_attach((GClosure *)rclosure, self);
+    i = g_signal_connect_closure_by_id(RVAL2GOBJ(self), signal_id, detail, rclosure, after);
 
     return INT2FIX(i);
 }
 
+static VALUE
+gobj_sig_connect(argc, argv, self)
+    int argc;
+    VALUE *argv;
+    VALUE self;
+{
+    return gobj_sig_connect_impl(FALSE, argc, argv, self);
+}
+
 static VALUE
 gobj_sig_connect_after(argc, argv, self)
     int argc;
     VALUE *argv;
     VALUE self;
 {
-    VALUE sig, rest;
-    int i;
-    GClosure* rclosure;
-    const char* sig_name;
-    guint signal_id;
-    GQuark detail;
-
-    rb_scan_args(argc, argv, "1*", &sig, &rest);
-
-    if (SYMBOL_P(sig))
-        sig_name = rb_id2name(SYM2ID(sig));
-    else {
-        StringValue(sig);
-        sig_name = StringValuePtr(sig);
-    }
-
-    if (!g_signal_parse_name(sig_name, CLASS2GTYPE(CLASS_OF(self)), &signal_id, &detail, TRUE))
-        rb_raise(eNoSignalError, "no such signal: %s", sig_name);
-
-    rclosure = g_rclosure_new(G_BLOCK_PROC(), rest, 
-                              rbgobj_get_signal_func(signal_id));
-    i = g_signal_connect_closure_by_id(RVAL2GOBJ(self), signal_id, detail, rclosure, TRUE);
-
-    return INT2FIX(i);
+    return gobj_sig_connect_impl(TRUE, argc, argv, self);
 }
 
 #if 0
@@ -395,7 +383,7 @@ gobj_sig_emit(argc, argv, self)
     g_signal_query(signal_id, &arg.query);
 
     if (arg.query.n_params != RARRAY(arg.args)->len)
-        rb_raise(rb_eArgError, "wrong number of arguments(%d for %d)",
+        rb_raise(rb_eArgError, "wrong number of arguments(%ld for %d)",
                  RARRAY(arg.args)->len + 1,
                  arg.query.n_params + 1);
 
@@ -605,6 +593,7 @@ gobj_s_method_added(klass, id)
         VALUE proc = rb_funcall(f, rb_intern("call"), 2, klass, id);
         GClosure* rclosure = g_rclosure_new(proc, Qnil,
                                             rbgobj_get_signal_func(signal_id));
+        g_rclosure_attach((GClosure *)rclosure, klass);
         g_signal_override_class_closure(signal_id, cinfo->gtype, rclosure);
     }
 
@@ -838,6 +827,7 @@ signal_add_emission_hook(int argc, VALUE* argv, VALUE self)
 
     closure = g_rclosure_new(proc, Qnil,
                              rbgobj_get_signal_func(query->signal_id));
+    g_rclosure_attach(closure, self);
     hook_id = g_signal_add_emission_hook_closure(query->signal_id, detail, closure);
     return ULONG2NUM(hook_id);
 }
