@@ -4,15 +4,19 @@
   rbgobj_type.c -
 
   $Author: mutoh $
-  $Date: 2005/10/15 04:31:38 $
+  $Date: 2006/06/18 13:42:33 $
   created at: Sun Jun  9 20:31:47 JST 2002
  
-  Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
+  Copyright (C) 2002-2006  Ruby-GNOME2 Project Team
   Copyright (C) 2002,2003  Masahiro Sakai
 
 **********************************************************************/
 
 #include "global.h"
+
+/**********************************************************************/
+/* Type Mapping */
+
 #ifdef RBGOBJ_USE_DLPTR
 #include "dl.h"
 #endif
@@ -22,8 +26,6 @@ static ID id_superclass;
 static VALUE gtype_to_cinfo;
 static VALUE klass_to_cinfo;
 
-static void rbgobj_init_interface(VALUE interf);
-
 static GHashTable* dynamic_gtype_list;
 typedef struct {
     const gchar* name;
@@ -54,14 +56,14 @@ rbgobj_lookup_class(klass)
     if (TYPE(klass) == T_CLASS) {
         VALUE super;
         if (FL_TEST(klass, FL_SINGLETON)) {
-            super = RCLASS(klass)->super;
+            super = rb_class_real(klass);
         } else {
             super = rb_funcall(klass, id_superclass, 0);
         }
         return rbgobj_lookup_class(super);
     }
 
-    rb_raise(rb_eRuntimeError, "can't get gobject class infomation");    
+    rb_raise(rb_eRuntimeError, "can't get gobject class information");    
 }
 
 static VALUE
@@ -84,7 +86,9 @@ get_superclass(gtype)
       case G_TYPE_FLAGS:
         return rb_cObject;
       default:
-        {
+        if (rbgobj_fund_has_type(gtype)) {
+          return rbgobj_fund_get_superclass(gtype);
+        } else {
             const RGObjClassInfo* cinfo_super =
                 rbgobj_lookup_class_by_gtype(g_type_parent(gtype), Qnil);
             return cinfo_super->klass;
@@ -119,12 +123,8 @@ rbgobj_lookup_class_by_gtype(gtype, parent)
     case G_TYPE_OBJECT:
     case G_TYPE_ENUM:
     case G_TYPE_FLAGS:
-      if (NIL_P(parent)){
-          cinfo->klass = rb_funcall(rb_cClass, id_new, 1,
-                                    get_superclass(gtype));
-      } else {
-          cinfo->klass = rb_funcall(rb_cClass, id_new, 1, parent);
-      }
+        if (NIL_P(parent)) parent = get_superclass(gtype);
+        cinfo->klass = rb_funcall(rb_cClass, id_new, 1, parent);
         break;
         
     case G_TYPE_INTERFACE:
@@ -133,12 +133,17 @@ rbgobj_lookup_class_by_gtype(gtype, parent)
         
     default:
         /* we should raise exception? */
-        fprintf(stderr,
-                "%s: %s's fundamental type %s isn't supported\n",
-                "rbgobj_lookup_class_by_gtype",
-                g_type_name(gtype),
-                g_type_name(G_TYPE_FUNDAMENTAL(gtype)));
-        return NULL;
+        if (rbgobj_fund_has_type(G_TYPE_FUNDAMENTAL(gtype))) {
+          if (NIL_P(parent)) parent = get_superclass(gtype);
+          cinfo->klass = rb_funcall(rb_cClass, id_new, 1, parent);
+        } else {
+          fprintf(stderr,
+                  "%s: %s's fundamental type %s isn't supported\n",
+                  "rbgobj_lookup_class_by_gtype",
+                  g_type_name(gtype),
+                  g_type_name(G_TYPE_FUNDAMENTAL(gtype)));
+          return NULL;
+          }
     
     }
 
@@ -180,6 +185,8 @@ rbgobj_lookup_class_by_gtype(gtype, parent)
         rbgobj_init_flags_class(cinfo->klass);
     } else if (G_TYPE_FUNDAMENTAL(gtype) == G_TYPE_INTERFACE) {
         rbgobj_init_interface(cinfo->klass);
+    } else {
+      rbgobj_fund_type_init_hook(G_TYPE_FUNDAMENTAL(gtype), cinfo->klass);
     }
     
     if (gclass)
@@ -247,7 +254,53 @@ rbgobj_register_class(VALUE klass,
         rb_hash_aset(gtype_to_cinfo, INT2NUM(gtype), c);
 }
 
+#define _register_fundamental_klass_to_gtype(klass, gtype) \
+    rbgobj_register_class(klass, gtype, TRUE, FALSE)
+
+#define _register_fundamental_gtype_to_klass(gtype,klass) \
+    rbgobj_register_class(klass, gtype, FALSE, TRUE)
+
+static void
+Init_typemap()
+{
+    id_new = rb_intern("new");
+    id_superclass = rb_intern("superclass");
+
+    rb_global_variable(&gtype_to_cinfo);
+    rb_global_variable(&klass_to_cinfo);
+    gtype_to_cinfo = rb_hash_new();
+    klass_to_cinfo = rb_hash_new();
+
+    _register_fundamental_klass_to_gtype(rb_cFixnum, G_TYPE_LONG);
+    _register_fundamental_klass_to_gtype(rb_cFloat, G_TYPE_DOUBLE);
+    _register_fundamental_klass_to_gtype(rb_cInteger, G_TYPE_LONG);
+    _register_fundamental_klass_to_gtype(rb_cString, G_TYPE_STRING);
+    _register_fundamental_klass_to_gtype(rb_cSymbol, G_TYPE_STRING);
+    _register_fundamental_klass_to_gtype(Qnil, G_TYPE_NONE);
+    _register_fundamental_klass_to_gtype(rb_cNilClass, G_TYPE_NONE);
+    _register_fundamental_klass_to_gtype(rb_cTrueClass, G_TYPE_BOOLEAN);
+    _register_fundamental_klass_to_gtype(rb_cFalseClass, G_TYPE_BOOLEAN);
+    _register_fundamental_klass_to_gtype(Qtrue, G_TYPE_BOOLEAN);
+    _register_fundamental_klass_to_gtype(Qfalse, G_TYPE_BOOLEAN);
+    _register_fundamental_klass_to_gtype(rb_cObject, RBGOBJ_TYPE_RUBY_VALUE);
+
+    _register_fundamental_gtype_to_klass(G_TYPE_UINT, rb_cInteger);
+    _register_fundamental_gtype_to_klass(G_TYPE_FLOAT, rb_cFloat);
+    _register_fundamental_gtype_to_klass(G_TYPE_DOUBLE, rb_cFloat);
+    _register_fundamental_gtype_to_klass(G_TYPE_INT64, rb_cInteger);
+    _register_fundamental_gtype_to_klass(G_TYPE_UINT64, rb_cInteger);
+    _register_fundamental_gtype_to_klass(G_TYPE_INT, rb_cInteger);
+    _register_fundamental_gtype_to_klass(G_TYPE_LONG, rb_cInteger);
+    _register_fundamental_gtype_to_klass(G_TYPE_CHAR, rb_cFixnum);
+    _register_fundamental_gtype_to_klass(G_TYPE_UCHAR, rb_cFixnum);
+    _register_fundamental_gtype_to_klass(G_TYPE_STRING, rb_cString);
+    _register_fundamental_gtype_to_klass(G_TYPE_ULONG, rb_cInteger);
+    _register_fundamental_gtype_to_klass(G_TYPE_NONE, rb_cNilClass);
+    _register_fundamental_gtype_to_klass(G_TYPE_BOOLEAN, rb_cTrueClass);
+}
+
 /**********************************************************************/
+/* GLib::Type */
 
 VALUE rbgobj_cType;
 static ID id_gtype;
@@ -684,236 +737,9 @@ Init_type()
 
 /**********************************************************************/
 
-VALUE mMetaInterface;
-
-static void 
-Init_interface_commons()
-{
-    mMetaInterface = rb_define_module_under(mGLib, "MetaInterface");
-    rb_define_method(mMetaInterface, "gtype", generic_s_gtype, 0);
-}
-
-/**********************************************************************/
-
-VALUE cInstantiatable;
-
-static VALUE
-instantiatable_s_allocate(klass)
-     VALUE klass;
-{
-     rb_raise(rb_eTypeError, "abstract class");
-}
-
-static VALUE
-instantiatable_get_gtype(self)
-    VALUE self;
-{
-    return rbgobj_gtype_new(G_TYPE_FROM_INSTANCE(rbgobj_instance_from_ruby_object(self)));
-}
-
-static VALUE
-instantiatable_clone(self)
-    VALUE self;
-{
-    rb_raise(rb_eTypeError, "can't clone %s", rb_class2name(CLASS_OF(self)));
-}
-
-static void
-Init_instantiatable()
-{
-    cInstantiatable = rb_define_class_under(mGLib, "Instantiatable", rb_cObject);
-    rb_extend_object(cInstantiatable, mMetaInterface);
-
-#ifndef HAVE_RB_DEFINE_ALLOC_FUNC
-    rb_define_singleton_method(cInstantiatable, "allocate", instantiatable_s_allocate, 0);
-#else
-    rb_define_alloc_func(cInstantiatable, (VALUE(*)_((VALUE)))instantiatable_s_allocate);
-#endif
-#ifndef HAVE_OBJECT_ALLOCATE
-    rb_define_singleton_method(cInstantiatable, "new", &generic_s_new, -1);
-#endif
-
-    rb_define_method(cInstantiatable, "gtype", instantiatable_get_gtype, 0);
-    rb_define_method(cInstantiatable, "clone", instantiatable_clone, 0);
-}
-
-/**********************************************************************/
-
-static VALUE
-interface_s_append_features(self, klass)
-     VALUE self, klass;
-{
-    if (!rb_obj_is_kind_of(klass, cInstantiatable))
-        rb_raise(rb_eTypeError, "Not a subclass of GLib::Instantiatable");
-    return rb_call_super(1, &klass);
-}
-
-#if GLIB_CHECK_VERSION(2,4,0)
-static VALUE
-interface_install_property(self, pspec_obj)
-    VALUE self, pspec_obj;
-{
-    const RGObjClassInfo* cinfo = rbgobj_lookup_class(self);
-    gpointer ginterface;
-    GParamSpec* pspec;
-
-    if (cinfo->klass != self)
-        rb_raise(rb_eTypeError, "%s isn't registered class",
-                 rb_class2name(self));
-
-    pspec = G_PARAM_SPEC(RVAL2GOBJ(pspec_obj));
-
-    ginterface = g_type_default_interface_ref(cinfo->gtype);
-    g_object_interface_install_property(ginterface, pspec);
-    g_type_default_interface_unref(ginterface);
-
-    /* FIXME: define accessor methods */
-    return Qnil;
-}
-
-static VALUE
-interface_property(self, property_name)
-     VALUE self, property_name;
-{
-    gpointer ginterface;
-    const char* name;
-    GParamSpec* prop;
-    VALUE result;
-
-    if (SYMBOL_P(property_name)) {
-        name = rb_id2name(SYM2ID(property_name));
-    } else {
-        StringValue(property_name);
-        name = StringValuePtr(property_name);
-    }
-
-    ginterface = g_type_default_interface_ref(CLASS2GTYPE(self));
-
-    prop = g_object_interface_find_property(ginterface, name);
-    if (!prop){
-        g_type_default_interface_unref(ginterface);
-        rb_raise(rb_const_get(mGLib, rb_intern("NoPropertyError")), 
-                 "no such property: %s", name);
-    }
-
-    result = GOBJ2RVAL(prop);
-    g_type_default_interface_unref(ginterface);
-    return result;
-}
-
-static VALUE
-interface_properties(int argc, VALUE* argv, VALUE self)
-{
-    guint n_properties;
-    GParamSpec** props;
-    VALUE inherited_too;
-    VALUE ary;
-    int i;
-    gpointer ginterface;
-
-    GType gtype  = CLASS2GTYPE(self);
-    ary = rb_ary_new();
-    if (gtype != G_TYPE_INTERFACE){
-        ginterface = g_type_default_interface_ref(gtype);
-
-        if (rb_scan_args(argc, argv, "01", &inherited_too) == 0)
-            inherited_too = Qtrue;
-        
-        props = g_object_interface_list_properties(ginterface, &n_properties);
-        
-        for (i = 0; i < n_properties; i++){
-            if (RTEST(inherited_too)
-                || GTYPE2CLASS(props[i]->owner_type) == self)
-                rb_ary_push(ary, rb_str_new2(props[i]->name));
-        }
-        g_free(props);
-        g_type_default_interface_unref(ginterface);
-    }
-    return ary;
-}
-#endif
-
-static void
-rbgobj_init_interface(interf)
-    VALUE interf;
-{
-    /* pseudo inheritance */
-    if (CLASS2GTYPE(interf) != G_TYPE_INTERFACE){
-        rb_extend_object(interf, GTYPE2CLASS(G_TYPE_INTERFACE));
-        rb_include_module(interf, GTYPE2CLASS(G_TYPE_INTERFACE));
-        rbgobj_define_property_accessors(interf);
-    }
-}
-
-static void
-Init_interface()
-{
-    VALUE iface = G_DEF_INTERFACE(G_TYPE_INTERFACE, "Interface", mGLib);
-
-    rb_define_method(mMetaInterface, "append_features", interface_s_append_features, 1);
-#if GLIB_CHECK_VERSION(2,4,0)
-    rb_define_method(mMetaInterface, "install_property", interface_install_property, 1);
-    rb_define_method(mMetaInterface, "property", interface_property, 1);
-    rb_define_method(mMetaInterface, "properties", interface_properties, -1);
-#endif
-
-    rb_extend_object(iface, mMetaInterface);
-    rb_include_module(iface, mMetaInterface);
-}
-
-/**********************************************************************/
-
-#define _register_fundamental_klass_to_gtype(klass, gtype) \
-    rbgobj_register_class(klass, gtype, TRUE, FALSE)
-
-#define _register_fundamental_gtype_to_klass(gtype,klass) \
-    rbgobj_register_class(klass, gtype, FALSE, TRUE)
-
-/*
- * Init
- */
 void Init_gobject_gtype()
 {
     g_type_init();
-
-    id_new = rb_intern("new");
-    id_superclass = rb_intern("superclass");
-
-    rb_global_variable(&gtype_to_cinfo);
-    rb_global_variable(&klass_to_cinfo);
-    gtype_to_cinfo = rb_hash_new();
-    klass_to_cinfo = rb_hash_new();
-
-    _register_fundamental_klass_to_gtype(rb_cFixnum, G_TYPE_LONG);
-    _register_fundamental_klass_to_gtype(rb_cFloat, G_TYPE_DOUBLE);
-    _register_fundamental_klass_to_gtype(rb_cInteger, G_TYPE_LONG);
-    _register_fundamental_klass_to_gtype(rb_cString, G_TYPE_STRING);
-    _register_fundamental_klass_to_gtype(rb_cSymbol, G_TYPE_STRING);
-    _register_fundamental_klass_to_gtype(Qnil, G_TYPE_NONE);
-    _register_fundamental_klass_to_gtype(rb_cNilClass, G_TYPE_NONE);
-    _register_fundamental_klass_to_gtype(rb_cTrueClass, G_TYPE_BOOLEAN);
-    _register_fundamental_klass_to_gtype(rb_cFalseClass, G_TYPE_BOOLEAN);
-    _register_fundamental_klass_to_gtype(Qtrue, G_TYPE_BOOLEAN);
-    _register_fundamental_klass_to_gtype(Qfalse, G_TYPE_BOOLEAN);
-    _register_fundamental_klass_to_gtype(rb_cObject, RBGOBJ_TYPE_RUBY_VALUE);
-
-    _register_fundamental_gtype_to_klass(G_TYPE_UINT, rb_cInteger);
-    _register_fundamental_gtype_to_klass(G_TYPE_FLOAT, rb_cFloat);
-    _register_fundamental_gtype_to_klass(G_TYPE_DOUBLE, rb_cFloat);
-    _register_fundamental_gtype_to_klass(G_TYPE_INT64, rb_cInteger);
-    _register_fundamental_gtype_to_klass(G_TYPE_UINT64, rb_cInteger);
-    _register_fundamental_gtype_to_klass(G_TYPE_INT, rb_cInteger);
-    _register_fundamental_gtype_to_klass(G_TYPE_LONG, rb_cInteger);
-    _register_fundamental_gtype_to_klass(G_TYPE_CHAR, rb_cFixnum);
-    _register_fundamental_gtype_to_klass(G_TYPE_UCHAR, rb_cFixnum);
-    _register_fundamental_gtype_to_klass(G_TYPE_STRING, rb_cString);
-    _register_fundamental_gtype_to_klass(G_TYPE_ULONG, rb_cInteger);
-    _register_fundamental_gtype_to_klass(G_TYPE_NONE, rb_cNilClass);
-    _register_fundamental_gtype_to_klass(G_TYPE_BOOLEAN, rb_cTrueClass);
-
+    Init_typemap();
     Init_type();
-
-    Init_interface_commons();
-    Init_instantiatable();
-    Init_interface();
 }
