@@ -4,9 +4,9 @@
   rbgobject.h -
 
   $Author: mutoh $
-  $Date: 2005/11/06 06:41:14 $
+  $Date: 2006/06/29 18:16:05 $
 
-  Copyright (C) 2003,2004  Ruby-GNOME2 Project Team
+  Copyright (C) 2003,2006  Ruby-GNOME2 Project Team
   Copyright (C) 2002,2003  Masahiro Sakai
 
 **********************************************************************/
@@ -42,15 +42,19 @@ extern "C" {
 #define G_DEF_INTERFACE2(gtype, name, module, mark, free)\
     (rbgobj_define_class(gtype, name, module, mark, free, Qnil))
 
+#define G_DEF_FUNDAMENTAL(f) (rbgobj_fund_define_fundamental(f))
+
 #define G_RELATIVE(obj, rel) (rbgobj_add_relative(obj, rel))
 
 /* G_RELATIVE2 is useless now. Try G_CHILD_ADD/REMOVE first. */
 #define G_RELATIVE2(obj, rel, id, hash_key)\
  (rbgobj_add_relative_removable(obj, rel, id, hash_key))
+#define G_GET_RELATIVE(obj, id, hash_key)\
+ (rbgobj_get_relative_removable(obj, id, hash_key))
 #define G_REMOVE_RELATIVE(obj, id, hash_key)\
  (rbgobj_remove_relative(obj, id, hash_key))
 
-extern ID rbgobj_id_children;
+RUBY_GLIB2_VAR  ID rbgobj_id_children;
 #define G_CHILD_SET(self, id, child)  (rb_ivar_set(self, id, child))
 #define G_CHILD_UNSET(self, id)  (rb_ivar_set(self, id, Qnil))
 
@@ -114,10 +118,13 @@ typedef struct {
 extern void rbgobj_initialize_object(VALUE obj, gpointer cobj);
 extern gpointer rbgobj_instance_from_ruby_object(VALUE obj);
 extern VALUE rbgobj_ruby_object_from_instance(gpointer instance);
+extern VALUE rbgobj_ruby_object_from_instance2(gpointer instance, gboolean alloc);
 
 extern void rbgobj_add_relative(VALUE obj, VALUE relative);
 extern void rbgobj_add_relative_removable(VALUE obj, VALUE relative,
                                           ID obj_ivar_id, VALUE hash_key);
+extern VALUE rbgobj_get_relative_removable(VALUE obj, ID obj_ivar_id,
+                                           VALUE hash_key);
 extern void rbgobj_remove_relative(VALUE obj, ID obj_ivar_id, VALUE hash_key);
 extern void rbgobj_remove_relative_all(VALUE obj, ID obj_ivar_id);
 
@@ -126,6 +133,9 @@ extern VALUE rbgobj_create_object(VALUE klass);
 
 extern void rbgobj_add_abstract_but_create_instance_class(GType gtype);
 
+/* rbgobj_typeinstance.c */
+extern void rbgobj_gc_mark_instance(gpointer instance);
+
 
 /* rbgobj_type.c */
 extern const RGObjClassInfo* rbgobj_lookup_class(VALUE klass);
@@ -151,8 +161,9 @@ extern VALUE rbgobj_signal_wrap(guint sig_id);
 
 
 /* rbgobj_closure.c */
-extern GClosure* g_rclosure_new(VALUE callback_proc, VALUE extra_args, 
+extern GClosure* g_rclosure_new(VALUE callback_proc, VALUE extra_args,
                                 GValToRValSignalFunc func);
+extern void g_rclosure_attach(GClosure *closure, VALUE object);
 
 /* rbgobj_value.c */
 extern VALUE rbgobj_gvalue_to_rvalue(const GValue* value);
@@ -163,6 +174,8 @@ typedef VALUE (*GValueToRValueFunc)(const GValue* from);
 extern void rbgobj_register_r2g_func(GType gtype, RValueToGValueFunc func);
 extern void rbgobj_register_g2r_func(GType gtype, GValueToRValueFunc func);
 
+extern void rbgobj_gc_mark_gvalue(GValue* value);
+
 /* rbgobj_valuetypes.c */
 extern VALUE rbgobj_ptr_new(GType type, gpointer ptr);
 extern gpointer rbgobj_ptr2cptr(VALUE ptr);
@@ -197,6 +210,8 @@ extern void rbgobj_define_const(VALUE mod, const char *name, VALUE value);
 /* rbglib_mainloop.c */
 #define G_TYPE_MAIN_LOOP (g_main_loop_get_type())
 extern GType g_main_loop_get_type(void);
+extern void rbg_remove_internal_poll_func(VALUE data);
+extern void rbg_set_internal_poll_func(void);
 
 /* rbglib_maincontext.c */
 #define G_TYPE_MAIN_CONTEXT (g_main_context_get_type())
@@ -206,6 +221,28 @@ extern GType g_main_context_get_type(void);
 extern GType g_source_get_type(void);
 extern GType g_poll_fd_get_type(void);
 
+/* rbgobj_fundamental.c */
+typedef struct {
+  GType type;
+  VALUE (*get_superclass)(void); 
+  void (*type_init_hook)(VALUE);
+  void (*rvalue2gvalue)(VALUE val, GValue *result);
+  VALUE (*gvalue2rvalue)(const GValue *);
+  void (*initialize)(VALUE, gpointer);
+  gpointer (*robj2instance)(VALUE);
+  VALUE (*instance2robj)(gpointer);
+} RGFundamental;
+
+extern void rbgobj_fund_define_fundamental(RGFundamental *f);
+extern gboolean rbgobj_fund_has_type(GType type);
+extern VALUE rbgobj_fund_get_superclass(GType type);
+extern void rbgobj_fund_type_init_hook(GType type, VALUE klass);
+extern VALUE rbgobj_fund_gvalue2rvalue(GType type, const GValue *value);
+extern gboolean rbgobj_fund_rvalue2gvalue(GType type, VALUE val, GValue *result);
+extern void rbgobj_fund_initialize(GType type, VALUE obj, gpointer cobj);
+extern gpointer rbgobj_fund_robj2instance(GType type, VALUE obj);
+extern VALUE rbgobj_fund_instance2robj(GType type, gpointer instance);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
