@@ -1,5 +1,5 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/* $Id: rbgnome-app-helper.c,v 1.14 2003/11/08 18:49:45 mutoh Exp $ */
+/* $Id: rbgnome-app-helper.c,v 1.17 2006/04/23 11:40:53 ktou Exp $ */
 /* based on libgnomeui/gnome-app-helper.h */
 
 /* Gnome::UIInfo module for Ruby/GNOME2
@@ -450,6 +450,12 @@ do_ui_signal_connect(uiinfo, signal_name, uibdata)
         return;
     args = rb_ary_new3(1, (VALUE)uiinfo->user_data);
     rclosure = g_rclosure_new(proc, args, NULL);
+    /* FIX ME: GOBJ2RVAL(uiinfo->widget) will be GCed. This
+       is same problem as the following:
+         Gtk::Window.new.show_all.signal_connect("destroy") {p :destroyed}
+       In the above sample, callback can't be invoked when
+       the object made by "Gtk::Window.new" is GCed. */
+    g_rclosure_attach(rclosure, GOBJ2RVAL(uiinfo->widget));
     g_signal_connect_closure(G_OBJECT(uiinfo->widget),
                              signal_name, rclosure, FALSE);
 }
@@ -773,6 +779,19 @@ app_fill_menus(self, menuinfo, accel_group, uline_accels, pos)
     return ui_info_to_ary(DATA_PTR(uiinfo));
 }
 
+static VALUE
+gno_s_accelerators_sync(self)
+    VALUE self;
+{
+    gnome_accelerators_sync();
+    return self;
+}
+
+/* How can I implement this?
+void        gnome_app_ui_configure_configurable
+                                            (GnomeUIInfo *uiinfo);
+*/
+
 static VALUE
 app_create_menus(self, menuinfo)
     VALUE self, menuinfo;
@@ -986,11 +1005,13 @@ Init_gnome_app_helper(mGnome)
     rb_define_module_function(mGnomeUIInfo, "menu_help_tree", uiinfo_menu_help_tree, 1);
     rb_define_module_function(mGnomeUIInfo, "menu_game_tree", uiinfo_menu_game_tree, 1);
 
-    /*
-     * instance methods
-     */
+    /* Misc methods */
+    rb_define_module_function(mGnome, "accelerators_sync", gno_s_accelerators_sync, 0);
+
     rb_define_method(gtkMenuShell, "fill_menus", app_fill_menus, 4);
+
     rb_define_method(gnoApp, "create_menus", app_create_menus, 1);
+
     rb_define_method(gtkToolBar, "fill_toolbar", app_fill_toolbar, 2);
     rb_define_method(gnoApp, "create_toolbar", app_create_toolbar, 1);
     rb_define_method(gtkMenuShell, "find_menu_pos", app_find_menu_pos, 1);
