@@ -1,8 +1,8 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
-/* $Id: rbgnome-canvas-item.c,v 1.19 2005/02/15 07:29:36 mutoh Exp $ */
+/* $Id: rbgnome-canvas-item.c,v 1.22 2006/04/15 01:07:04 ktou Exp $ */
 
 /* Gnome::CanvasItem widget for Ruby/Gnome
- * Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
+ * Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
  * Copyright (C) 2001 Neil Conway <neilconway@rogers.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -33,6 +33,8 @@
 #define va_init_list(a,b) va_start(a)
 #endif
 
+static VALUE citem_parent(VALUE self);
+
 static void
 #ifdef HAVE_STDARG_PROTOTYPES
 citem_do_construct(GnomeCanvasItem *item, GnomeCanvasGroup *parent, const gchar *first_arg_name, ...)
@@ -57,6 +59,10 @@ citem_intialize(self, parent, hash)
     GnomeCanvasItem *item;
     GnomeCanvasGroup *group;
 
+    if (! rb_obj_is_kind_of(parent, GTYPE2CLASS(GNOME_TYPE_CANVAS_GROUP))){
+        rb_raise(rb_eArgError, "the 1st parameter should be Gnome::CanvasGroup");
+    }
+
     group = GNOME_CANVAS_GROUP(RVAL2GOBJ(parent));
     item = GNOME_CANVAS_ITEM(g_object_new(RVAL2GTYPE(self), NULL));
     RBGTK_INITIALIZE(self, item);
@@ -68,6 +74,8 @@ citem_intialize(self, parent, hash)
 
     g_object_thaw_notify(G_OBJECT(item));
 
+    G_CHILD_ADD(parent, self);
+
     return Qnil;
 }
 
@@ -221,7 +229,9 @@ citem_reparent(self, new_group)
     if (!g_type_is_a(RVAL2GTYPE(new_group), GNOME_TYPE_CANVAS_GROUP)) {
         rb_raise(rb_eTypeError, "not a GnomeCanvasGroup");
     }
+    G_CHILD_REMOVE(citem_parent(self), self);
     gnome_canvas_item_reparent(_SELF(self), GNOME_CANVAS_GROUP(RVAL2GOBJ(new_group)));
+    G_CHILD_ADD(new_group, self);
     return self;
 }
 
@@ -274,7 +284,7 @@ citem_shape_set_path_def(self, def)
     VALUE self, def;
 {
     gnome_canvas_shape_set_path_def(GNOME_CANVAS_SHAPE(RVAL2GOBJ(self)), 
-                                    (GnomeCanvasPathDef*)RVAL2BOXED(def, rbgno_canvas_path_def_get_type()));
+                                    (GnomeCanvasPathDef*)RVAL2BOXED(def, GNOME_TYPE_CANVAS_PATH_DEF));
     return self;
 }
 
@@ -282,7 +292,7 @@ static VALUE
 citem_shape_get_path_def(self)
     VALUE self;
 {
-    return BOXED2RVAL(gnome_canvas_shape_get_path_def(GNOME_CANVAS_SHAPE(RVAL2GOBJ(self))), rbgno_canvas_path_def_get_type());
+    return BOXED2RVAL(gnome_canvas_shape_get_path_def(GNOME_CANVAS_SHAPE(RVAL2GOBJ(self))), GNOME_TYPE_CANVAS_PATH_DEF);
 }
 
 void
