@@ -18,9 +18,9 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  *
- * $Author: mutoh $
+ * $Author: sakai $
  *
- * $Date: 2005/07/24 07:34:43 $
+ * $Date: 2006/06/13 16:03:48 $
  *
  *****************************************************************************/
 
@@ -32,6 +32,8 @@
 /* Defines *******************************************************************/
 
 #define _SELF(s)	((GnomeVFSHandle *)RVAL2BOXED(s, GNOMEVFS_TYPE_FILE))
+#define RVAL2OPENMODE(x) ((GnomeVFSOpenMode)(RVAL2GFLAGS(x,GNOME_VFS_TYPE_VFS_OPEN_MODE)))
+#define OPENMODE2RVAL(x) (GFLAGS2RVAL(x,GNOME_VFS_TYPE_VFS_OPEN_MODE))
 
 /* Type Definitions **********************************************************/
 
@@ -39,8 +41,6 @@
 
 /* Global Variables **********************************************************/
 
-static VALUE s_default_rsep;
-
 /* Function Implementations **************************************************/
 
 static GnomeVFSHandle *
@@ -187,7 +187,7 @@ file_m_chmod(argc, argv, self)
   rb_secure(2);
   info = gnome_vfs_file_info_new();
   rb_scan_args(argc, argv, "1*", &r_mode, &paths);
-  info->permissions = FIX2INT(r_mode);
+  info->permissions = RVAL2GFLAGS(r_mode, GNOME_VFS_TYPE_VFS_FILE_PERMISSIONS);
   value = apply_set_info(paths, info,
                          GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
   gnome_vfs_file_info_unref(info);
@@ -211,12 +211,12 @@ file_m_chown(argc, argv, self)
   if (NIL_P(r_owner)) {
     info->uid = (guint)-1;
   } else {
-    info->uid = FIX2INT(r_owner);
+    info->uid = NUM2INT(r_owner);
   }
   if (NIL_P(r_group)) {
     info->gid = (guint)-1;
   } else {
-    info->gid = FIX2INT(r_group);
+    info->gid = NUM2INT(r_group);
   }
 
   value = apply_set_info(paths, info, GNOME_VFS_SET_FILE_INFO_OWNER);
@@ -236,7 +236,7 @@ file_m_lstat(argc, argv, self)
   GnomeVFSResult result;
 
   if (rb_scan_args(argc, argv, "11", &uri, &r_options) == 1) {
-    options = FIX2INT(r_options);
+    options = RVAL2GFLAGS(r_options, GNOME_VFS_TYPE_VFS_FILE_INFO_OPTIONS);
   } else {
     options = GNOME_VFS_FILE_INFO_DEFAULT;
   }
@@ -268,7 +268,7 @@ file_m_stat(argc, argv, self)
   GnomeVFSResult result;
 
   if (rb_scan_args(argc, argv, "11", &uri, &r_options) == 1) {
-    options = FIX2INT(r_options);
+    options = RVAL2GFLAGS(r_options, GNOME_VFS_TYPE_VFS_FILE_INFO_OPTIONS);
   } else {
     options = GNOME_VFS_FILE_INFO_DEFAULT;
   }
@@ -298,11 +298,11 @@ file_m_set_stat(self, uri, info, mask)
   if (RTEST(rb_obj_is_kind_of(uri, g_gvfs_uri))) {
     result = gnome_vfs_set_file_info_uri(RVAL2GVFSURI(uri),
                                          RVAL2GVFSFILEINFO(info),
-                                         FIX2INT(mask));
+                                         RVAL2GFLAGS(mask, GNOME_VFS_TYPE_VFS_SET_FILE_INFO_MASK));
   } else {
     result = gnome_vfs_set_file_info(RVAL2CSTR(uri),
                                      RVAL2GVFSFILEINFO(info),
-                                     FIX2INT(mask));
+                                     RVAL2GFLAGS(mask, GNOME_VFS_TYPE_VFS_SET_FILE_INFO_MASK));
   }
 
   return GVFSRESULT2RVAL(result);
@@ -408,8 +408,8 @@ get_gets_separator(argc, argv, sep, len)
     *sep = RSTRING(r_separator)->ptr;
     *len = RSTRING(r_separator)->len;
   } else {
-    *sep = RSTRING(s_default_rsep)->ptr;
-    *len = RSTRING(s_default_rsep)->len;
+    *sep = RSTRING(rb_rs)->ptr;
+    *len = RSTRING(rb_rs)->len;
   }
 }
 
@@ -435,33 +435,34 @@ file_initialize(argc, argv, self)
     exclusive = Qfalse;
   }
   if (argc < 2) {
-    open_mode = INT2FIX(GNOME_VFS_OPEN_READ);
+    open_mode = OPENMODE2RVAL(GNOME_VFS_OPEN_READ);
   }
 
+  printf ("open_mode = %d\n", RVAL2OPENMODE(open_mode));
   if (RTEST(rb_obj_is_kind_of(uri, g_gvfs_uri))) {
-    if (argc < 3) {
       result = gnome_vfs_open_uri(&handle,
                                   RVAL2GVFSURI(uri),
-                                  FIX2INT(open_mode));
-    } else {
-      result = gnome_vfs_create_uri(&handle,
-                                    RVAL2GVFSURI(uri),
-                                    FIX2INT(open_mode),
-                                    RTEST(exclusive),
-                                    FIX2INT(perm));
-    }
+                                  RVAL2OPENMODE(open_mode));
+      if (result == GNOME_VFS_ERROR_NOT_FOUND && 
+          (RVAL2OPENMODE(open_mode) & GNOME_VFS_OPEN_WRITE)){
+        result = gnome_vfs_create_uri(&handle,
+                                      RVAL2GVFSURI(uri),
+                                      RVAL2OPENMODE(open_mode),
+                                      RTEST(exclusive),
+                                      NUM2UINT(perm));
+      }
   } else {
-    if (argc < 3) {
       result = gnome_vfs_open(&handle,
                               RVAL2CSTR(uri),
-                              FIX2INT(open_mode));
-    } else {
-      result = gnome_vfs_create(&handle,
-                                RVAL2CSTR(uri),
-                                FIX2INT(open_mode),
-                                RTEST(exclusive),
-                                FIX2INT(perm));
-    }
+                              RVAL2OPENMODE(open_mode));
+      if (result == GNOME_VFS_ERROR_NOT_FOUND && 
+          (RVAL2OPENMODE(open_mode) & GNOME_VFS_OPEN_WRITE)){
+        result = gnome_vfs_create(&handle,
+                                  RVAL2CSTR(uri),
+                                  RVAL2OPENMODE(open_mode),
+                                  RTEST(exclusive),
+                                  NUM2UINT(perm));
+      }
   }
 
   RAISE_IF_ERROR(result);
@@ -601,7 +602,7 @@ file_putc(self, r_c)
   guint8 c;
   GnomeVFSFileSize bytes_written;
 
-  c = FIX2UINT(r_c) & 0xff;
+  c = NUM2UINT(r_c) & 0xff;
   return GVFSRESULT2RVAL(gnome_vfs_write(_SELF(self), &c, 1ULL, 
                                          &bytes_written));
 }
@@ -626,127 +627,76 @@ file_write(self, str)
   return CHECK_RESULT(result, ULL2NUM(bytes_written));
 }
 
-static VALUE
-file_printf(argc, argv, self)
-     int argc;
-     VALUE *argv;
-     VALUE self;
-{
-  file_write(self, rb_f_sprintf(argc, argv));
-  return Qnil;
-}
-
-static VALUE file_puts(int argc, VALUE *argv, VALUE self);
-
-#ifdef HAVE_RB_EXEC_RECURSIVE
-static VALUE
-file_puts_ary(ary, self, recur)
-     VALUE ary, self, recur;
-{
-  VALUE tmp;
-  long i;
-
-  for (i = 0; i < RARRAY(ary)->len; i++) {
-    tmp = RARRAY(ary)->ptr[i];
-    if (recur) {
-      tmp = rb_str_new2("[...]");
-    }
-    file_puts(1, &tmp, self);
-  }
-
-  return Qnil;
-}
-#else
-static VALUE
-file_puts_ary(ary, self)
-     VALUE ary, self;
-{
-  VALUE tmp;
-  int i;
-  int n;
-
-  for (i = 0, n = RARRAY(ary)->len; i < n; i++) {
-    tmp = RARRAY(ary)->ptr[i];
-    if (rb_inspecting_p(tmp)) {
-      tmp = rb_str_new2("[...]");
-    }
-    file_puts(1, &tmp, self);
-  }
-
-  return Qnil;
-}
-#endif
-
-static VALUE
-file_puts(argc, argv, self)
-     int argc;
-     VALUE *argv;
-     VALUE self;
-{
-  VALUE line;
-  int i;
-
-  if (argc > 0) {
-    for (i = 0; i < argc; i++) {
-      if (NIL_P(argv[i])) {
-        line = rb_str_new2("nil");
-      } else {
-        line = rb_check_convert_type(argv[i],
-                                     T_ARRAY,
-                                     "Array",
-                                     "to_ary");
-        if (!NIL_P(line)) {
-#ifdef HAVE_RB_EXEC_RECURSIVE
-          rb_exec_recursive(file_puts_ary, line, self);
-#else
-          rb_protect_inspect(file_puts_ary, line,
-                             self);
-#endif
-          continue;
-        }
-        line = rb_obj_as_string(argv[i]);
-      }
-      file_write(self, line);
-      if (RSTRING(line)->ptr[RSTRING(line)->len - 1]
-          != '\n') {
-        file_write(self, s_default_rsep);
-      }
-    }
-  } else {
-    file_write(self, s_default_rsep);
-    return Qnil;
-  }
-  return Qnil;
-}
-
-static VALUE
-bytes_from_end(self)
-     VALUE self;
+static GnomeVFSFileSize
+remain_size(handle)
+     GnomeVFSHandle* handle;
 {
   GnomeVFSFileInfo *info;
   GnomeVFSFileSize offset;
   GnomeVFSResult result;
-  VALUE value;
+  GnomeVFSFileSize value = BUFSIZ;
 
   info = gnome_vfs_file_info_new();
-  result = gnome_vfs_get_file_info_from_handle(_SELF(self), info,
+  result = gnome_vfs_get_file_info_from_handle(handle, info,
                                                GNOME_VFS_FILE_INFO_DEFAULT);
   if (result == GNOME_VFS_OK) {
-    result = gnome_vfs_tell(_SELF(self), &offset);
+    result = gnome_vfs_tell(handle, &offset);
     if (result == GNOME_VFS_OK) {
       /* XXX: is the + 1 right? */
-      value = ULL2NUM(info->size - offset + 1);
-    } else {
-      value = GVFSRESULT2RVAL(result);
+      value = info->size - offset + 1;
     }
-  } else {
-    value = GVFSRESULT2RVAL(result);
   }
 
   gnome_vfs_file_info_unref(info);
+
+  if (value > LONG_MAX)
+      rb_raise(rb_eIOError, "file too big for single read");
   return value;
 }
 
+static VALUE
+read_all(handle, siz, str)
+     GnomeVFSHandle *handle;
+     GnomeVFSFileSize siz;
+     VALUE str;
+{
+  GnomeVFSFileSize bytes = 0;
+  
+  if (siz == 0) siz = BUFSIZ;
+  if (NIL_P(str)) {
+    str = rb_tainted_str_new(0, siz);
+  } else {
+    StringValue(str);
+    rb_str_modify(str);
+    rb_str_resize(str, siz);
+  }
+  
+  for (;;) {
+    GnomeVFSFileSize bytes_read;
+    GnomeVFSResult result;
+  
+    result = gnome_vfs_read(handle,
+                            RSTRING(str)->ptr + bytes,
+                            siz - bytes,
+                            &bytes_read);
+    
+    if (result == GNOME_VFS_OK) {
+    	bytes += bytes_read;
+        if (siz - bytes < BUFSIZ) {
+          siz += BUFSIZ;
+          rb_str_resize(str, siz);
+    	}
+    } else if (result == GNOME_VFS_ERROR_EOF) {
+      rb_str_resize(str, bytes);
+      break;
+    } else {
+      GVFSRESULT2RVAL(result);
+    }
+  }
+  
+  return str;
+}
+
 static VALUE
 file_read(argc, argv, self)
      int argc;
@@ -754,33 +704,33 @@ file_read(argc, argv, self)
      VALUE self;
 {
   VALUE len, str;
+  GnomeVFSHandle* handle = _SELF(self);
   GnomeVFSFileSize bytes;
   GnomeVFSFileSize bytes_read;
   GnomeVFSResult result;
 
-  if (rb_scan_args(argc, argv, "01", &len) == 1) {
-    bytes = NUM2INT(len);
-  } else {
-    VALUE bytes_left;
-
-    bytes_left = bytes_from_end(self);
-    if (!NIL_P(bytes_left)) {
-      bytes = NUM2ULONG(bytes_left);
-    } else {
-      return Qnil;
-    }
-  }
+  rb_scan_args(argc, argv, "02", &len, &str);
+  if (NIL_P(len))
+    return read_all(handle, remain_size(handle), str);
 
+  bytes = NUM2INT(len);
   if (bytes < 0) {
-    rb_raise(rb_eArgError, "negative length %d given", bytes);
+    /* FIXME */
+    rb_raise(rb_eArgError, "negative length %ld given", (long)bytes);
   }
 
-  str = rb_str_new(0, bytes);
+  if (NIL_P(str)) {
+    str = rb_tainted_str_new(0, bytes);
+  } else {
+    StringValue(str);
+    rb_str_modify(str);
+    rb_str_resize(str, bytes);
+  }
   if (bytes == 0) {
     return str;
   }
 
-  result = gnome_vfs_read(_SELF(self), RSTRING(str)->ptr, bytes,
+  result = gnome_vfs_read(handle, RSTRING(str)->ptr, bytes,
                           &bytes_read);
   if (result == GNOME_VFS_OK) {
     RSTRING(str)->len = bytes_read;
@@ -858,7 +808,7 @@ file_seek(argc, argv, self)
   GnomeVFSSeekPosition whence;
 
   if (rb_scan_args(argc, argv, "11", &offset, &r_whence) == 2) {
-    whence = FIX2INT(r_whence);
+    whence = RVAL2GENUM(r_whence, GNOME_VFS_TYPE_VFS_SEEK_POSITION);
   } else {
     whence = GNOME_VFS_SEEK_START;
   }
@@ -879,7 +829,7 @@ file_stat(argc, argv, self)
   GnomeVFSResult result;
 
   if (rb_scan_args(argc, argv, "01", &r_options) == 1) {
-    options = FIX2INT(r_options);
+    options = RVAL2GFLAGS(r_options, GNOME_VFS_TYPE_VFS_FILE_INFO_OPTIONS);
   } else {
     options = GNOME_VFS_FILE_INFO_DEFAULT;
   }
@@ -903,8 +853,6 @@ void
 Init_gnomevfs_file(m_gvfs)
      VALUE m_gvfs;
 {
-  s_default_rsep = rb_str_new2("\n");
-
   g_gvfs_file = G_DEF_CLASS(GNOMEVFS_TYPE_FILE, "File", m_gvfs);
   rb_include_module(g_gvfs_file, rb_mEnumerable);
 
@@ -939,10 +887,7 @@ Init_gnomevfs_file(m_gvfs)
   rb_define_method(g_gvfs_file, "gets", file_gets, -1);
   rb_define_method(g_gvfs_file, "pos", file_pos, -1);
   rb_define_method(g_gvfs_file, "tell", file_tell, 0);
-  rb_define_method(g_gvfs_file, "printf", file_printf, -1);
   rb_define_method(g_gvfs_file, "putc", file_putc, 1);
-  rb_define_method(g_gvfs_file, "puts", file_puts, -1);
-  rb_define_alias(g_gvfs_file, "print", "puts");
   rb_define_method(g_gvfs_file, "read", file_read, -1);
   rb_define_method(g_gvfs_file, "readchar", file_readchar, 0);
   rb_define_method(g_gvfs_file, "readline", file_readline, -1);
@@ -953,20 +898,15 @@ Init_gnomevfs_file(m_gvfs)
   rb_define_method(g_gvfs_file, "file_info", file_stat, -1);
   rb_define_method(g_gvfs_file, "truncate", file_truncate, 1);
   rb_define_method(g_gvfs_file, "write", file_write, 1);
-  rb_define_alias(g_gvfs_file, "<<", "write");
+  rb_define_method(g_gvfs_file, "printf", rb_io_printf, -1);
+  rb_define_method(g_gvfs_file, "puts", rb_io_puts, -1);
+  rb_define_method(g_gvfs_file, "print", rb_io_print, -1);
+  rb_define_method(g_gvfs_file, "<<", rb_io_addstr, 1);
 
-  rb_define_const(g_gvfs_file,
-                  "OPEN_NONE",
-                  INT2FIX(GNOME_VFS_OPEN_NONE));
-  rb_define_const(g_gvfs_file,
-                  "OPEN_READ",
-                  INT2FIX(GNOME_VFS_OPEN_READ));
-  rb_define_const(g_gvfs_file,
-                  "OPEN_WRITE",
-                  INT2FIX(GNOME_VFS_OPEN_WRITE));
-  rb_define_const(g_gvfs_file,
-                  "OPEN_RANDOM",
-                  INT2FIX(GNOME_VFS_OPEN_RANDOM));
+  G_DEF_CLASS(GNOME_VFS_TYPE_VFS_OPEN_MODE , "OpenMode", g_gvfs_file);
+  G_DEF_CONSTANTS(g_gvfs_file, GNOME_VFS_TYPE_VFS_OPEN_MODE, "GNOME_VFS_");
+
+  /* FIXME: GNOME_VFS_TYPE_VFS_SEEK_POSITION */
 }
 
 /* vim: set sts=0 sw=8 ts=8: *************************************************/
