@@ -232,6 +232,25 @@ rb_gst_pad_link (VALUE self, VALUE other_pad)
 	return CBOOL2RVAL (gst_pad_link (srcpad, sinkpad)); 
 }
  
+/*
+ * Method: link_filtered(other_pad, caps)
+ * other_pad: a Gst::Pad.
+ * caps: a Gst::Caps.
+ *
+ * Links the current pad (source) to an other pad (sink), constrained by
+ * the given filter caps.
+ *
+ * Returns: true if the pads have been linked, false otherwise.
+ */  
+static VALUE
+rb_gst_pad_link_filtered (VALUE self, VALUE other_pad, VALUE rcaps)
+{
+	GstPad *srcpad = RGST_PAD (self);
+	GstPad *sinkpad = RGST_PAD (other_pad);
+    GstCaps *caps = RGST_CAPS (rcaps);
+	return CBOOL2RVAL (gst_pad_link_filtered (srcpad, sinkpad, caps)); 
+}
+
 /*
  * Method: unlink(other_pad)
  * other_pad: a Gst::Pad.
@@ -330,21 +349,10 @@ rb_gst_pad_send_event (VALUE self, VALUE event)
 static VALUE
 rb_gst_pad_get_caps (VALUE self)
 {
-    return RGST_CAPS_NEW (gst_pad_get_caps (RGST_PAD (self))); 	
-}
-
-/*
- * Method: each_caps { |caps| ... }
- *
- * Calls the block for each capability of the pad, 
- * passing a reference to the Gst::Caps object as parameter.
- *
- * Returns: always nil.
- */
-static VALUE
-rb_gst_pad_each_caps (VALUE self)
-{
-	return rb_ary_yield (rb_gst_pad_get_caps (self));
+    GstCaps *caps = gst_pad_get_caps (RGST_PAD (self));
+    return caps != NULL
+        ? RGST_CAPS_NEW (caps)
+        : Qnil;
 }
 
 void
@@ -365,13 +373,13 @@ Init_gst_pad (void)
 	rb_define_method (c, "each_event_mask", rb_gst_pad_each_event_mask, 0);
 	rb_define_method (c, "each_query_type", rb_gst_pad_each_query_type, 0);
 	rb_define_method (c, "link", rb_gst_pad_link, 1);
+	rb_define_method (c, "link_filtered", rb_gst_pad_link_filtered, 2);
 	rb_define_method (c, "unlink", rb_gst_pad_unlink, 1);
 	rb_define_method (c, "disabled?", rb_gst_pad_is_disabled, 0);
 	rb_define_method (c, "negotiating?", rb_gst_pad_is_negotiating, 0);
 	rb_define_method (c, "query", rb_gst_pad_query,	-1);
 	rb_define_method (c, "send_event", rb_gst_pad_send_event, 1);
 	rb_define_method (c, "caps", rb_gst_pad_get_caps, 0);
-	rb_define_method (c, "each_caps", rb_gst_pad_each_caps ,0);
 
 	G_DEF_CLASS (GST_TYPE_PAD_LINK_RETURN, "LinkReturn", c);
 	G_DEF_CONSTANTS (c, GST_TYPE_PAD_LINK_RETURN, "GST_PAD_");
