@@ -54,6 +54,18 @@ if target=="x11"
   have_func("XGetErrorText")
 end
 
+PKGConfig.have_package('cairo')
+if have_header('rb_cairo.h')
+  if /mingw|cygwin|mswin32/ =~ RUBY_PLATFORM
+    unless ENV["CAIRO_PATH"]
+      puts "Error! Set CAIRO_PATH."
+      exit 1
+    end
+    add_depend_package("cairo", "packages/cairo/ext", ENV["CAIRO_PATH"])
+    $defs << "-DRUBY_CAIRO_PLATFORM_WIN32"
+  end
+end
+
 add_depend_package("glib2", "glib/src", TOPDIR)
 add_depend_package("pango", "pango/src", TOPDIR)
 
