@@ -2,16 +2,14 @@
 =begin
   main.rb - Main class of gtk-demo.
 
-  Copyright (c) 2003-2005 Ruby-GNOME2 Project Team
+  Copyright (c) 2003-2006 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: main.rb,v 1.17 2005/10/16 12:07:32 mutoh Exp $
+  $Id: main.rb,v 1.19 2006/06/17 13:18:12 mutoh Exp $
 =end
 
 require 'gtk2'
 
-Gtk.init
-
 module Demo
 
   class Main < Gtk::Window
@@ -215,6 +213,7 @@ module Demo
           iter.set_value(ITALIC_COLUMN, false)
         end
         window.show_all
+	@window = window
       end
     end
 
