@@ -1,17 +1,15 @@
 #!/usr/bin/env ruby
 =begin
-  window.rb - Ruby/GTK sample script.
+  window.rb - Gtk::Window sample.
 
-  Copyright (c) 2002-2005 Ruby-GNOME2 Project Team
+  Copyright (c) 2002-2006 Ruby-GNOME2 Project Team
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: window.rb,v 1.7 2005/07/14 17:01:50 mutoh Exp $
+  $Id: window.rb,v 1.8 2006/06/17 13:18:12 mutoh Exp $
 =end
 
 require 'gtk2'
 
-Gtk.init
-
 window = Gtk::Window.new("Gtk::Window sample")
 window.border_width = 10
 
