@@ -4,9 +4,9 @@
   rbgdkwindow.c -
 
   $Author: ggc $
-  $Date: 2005/09/23 19:17:01 $
+  $Date: 2006/06/22 19:52:54 $
 
-  Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
+  Copyright (C) 2002-2006 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
                           Daisuke Kanda,
                           Hiroshi Igarashi
@@ -409,7 +409,7 @@ gdkwin_get_update_area(self)
     VALUE self;
 {
     GdkRegion* ret = gdk_window_get_update_area(_SELF(self));
-    return ret ? BOXED2RVAL(ret, GDK_TYPE_REGION) : Qnil; 
+    return BOXED2RVAL(ret, GDK_TYPE_REGION); 
 }
 
 static VALUE
@@ -901,10 +901,7 @@ static VALUE
 gdkwin_s_get_toplevels(self)
     VALUE self;
 {
-    GList* list = gdk_window_get_toplevels();
-    VALUE ret = GLIST2ARY(list);
-    g_list_free(list);
-    return ret;
+    return GLIST2ARYF(gdk_window_get_toplevels());
 }
 
 static VALUE
