@@ -4,9 +4,9 @@
   rbgtkaction.c -
 
   $Author: mutoh $
-  $Date: 2005/01/11 17:01:39 $
+  $Date: 2006/06/17 06:59:32 $
 
-  Copyright (C) 2004,2005 Masao Mutoh
+  Copyright (C) 2004-2006 Masao Mutoh
 ************************************************/
 
 #include "global.h"
@@ -109,6 +109,7 @@ static VALUE
 action_get_proxies(self)
     VALUE self;
 {
+    /* Owned by GTK+ */
     return GSLIST2ARY(gtk_action_get_proxies(_SELF(self)));
 }
 
@@ -190,8 +191,17 @@ action_get_accel_path(self)
 {
     return CSTR2RVAL(gtk_action_get_accel_path(_SELF(self)));
 }
-
 #endif
+
+#if GTK_CHECK_VERSION(2,8,0)
+static VALUE
+action_get_accel_closure(self)
+    VALUE self;
+{
+    return BOXED2RVAL(gtk_action_get_accel_closure(_SELF(self)), G_TYPE_CLOSURE);
+}
+#endif
+
 #endif
 
 void 
@@ -230,6 +240,10 @@ Init_gtk_action()
     rb_define_method(gAction, "accel_path", action_get_accel_path, 0);
 #endif
 
+#if GTK_CHECK_VERSION(2,8,0)
+    rb_define_method(gAction, "accel_closure", action_get_accel_closure, 0);
+#endif
+
     G_DEF_SETTERS(gAction);
 #endif
 }
