@@ -4,9 +4,9 @@
   rbgtkcellview.c -
 
   $Author: mutoh $
-  $Date: 2005/05/05 19:57:29 $
+  $Date: 2006/06/17 06:59:32 $
 
-  Copyright (C) 2005 Masao Mutoh
+  Copyright (C) 2005,2006 Masao Mutoh
 ************************************************/
 
 #include "global.h"
@@ -15,6 +15,9 @@
 
 #define _SELF(self) (GTK_CELL_VIEW(RVAL2GOBJ(self)))
 
+static ID id_model;
+static ID id_text;
+
 static VALUE
 cview_initialize(argc, argv, self)
     int argc;
@@ -30,6 +33,7 @@ cview_initialize(argc, argv, self)
     if (NIL_P(text)) {
         widget = gtk_cell_view_new();
     } else {
+        G_CHILD_SET(self, id_text, text);
         if (TYPE(text) == T_STRING){
             if (NIL_P(with_markup) || RTEST(with_markup)){
                 widget = gtk_cell_view_new_with_markup(RVAL2CSTR(text));
@@ -54,6 +58,7 @@ static VALUE
 cview_set_model(self, model)
     VALUE self, model;
 {
+    G_CHILD_SET(self, id_model, model);
     gtk_cell_view_set_model(_SELF(self), 
                             NIL_P(model) ? (GtkTreeModel*)NULL : GTK_TREE_MODEL(RVAL2GOBJ(model)));
     return self;
@@ -101,10 +106,7 @@ static VALUE
 cview_get_cell_renderers(self)
     VALUE self;
 {
-    GList* list = gtk_cell_view_get_cell_renderers(_SELF(self));
-    VALUE ret = list ? GLIST2ARY(list) : Qnil;
-    g_list_free(list);
-    return ret;
+    return GLIST2ARYF(gtk_cell_view_get_cell_renderers(_SELF(self)));
 }
 #endif
 
@@ -114,6 +116,9 @@ Init_gtk_cellview()
 #if GTK_CHECK_VERSION(2,6,0)
     VALUE cview = G_DEF_CLASS(GTK_TYPE_CELL_VIEW, "CellView", mGtk);
 
+    id_model = rb_intern("model");
+    id_text = rb_intern("text");
+
     rb_define_method(cview, "initialize", cview_initialize, -1);
     rb_define_method(cview, "set_model", cview_set_model, 1);
     rb_define_method(cview, "set_displayed_row", cview_set_displayed_row, 1);
