@@ -3,8 +3,8 @@
 
   rbgtklabel.c -
 
-  $Author: mutoh $
-  $Date: 2005/01/09 19:02:05 $
+  $Author: ktou $
+  $Date: 2006/07/01 10:02:06 $
 
   Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
