@@ -4,8 +4,8 @@
 
   rbgtkmain.c -
 
-  $Author: silicio $
-  $Date: 2005/03/02 12:06:36 $
+  $Author: mutoh $
+  $Date: 2006/07/01 09:50:11 $
 
   Copyright (C) 2002,2003 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
@@ -19,14 +19,51 @@ EXTERN VALUE rb_progname, rb_argv;
 
 static VALUE rbgtk_main_threads = Qnil;
 
+static ID id__quit_callbacks__, id__timeout_callbacks__;
+static ID id__idle_callbacks__, id__snooper_callbacks__;
+
+
+typedef struct _callback_info_t
+{
+    VALUE callback;
+    ID key;
+    guint id;
+} callback_info_t;
+
+
+static VALUE
+gtk_m_function_body(data)
+    VALUE data;
+{
+    callback_info_t *info = (callback_info_t *)data;
+    VALUE ret = rb_funcall(info->callback, id_call, 0);
+
+    if (info->key && !ret)
+        G_REMOVE_RELATIVE(mGtk, info->key, UINT2NUM(info->id));
+    return ret;
+}
+
 static gboolean
 gtk_m_function(data)
     gpointer data;
-{
-    VALUE ret = rb_funcall((VALUE)data, id_call, 0);
-    return RTEST(ret);
+{ 
+    return RTEST(G_PROTECT_CALLBACK(gtk_m_function_body, data));
 }
 
+static VALUE
+gtk_m_function2_body(gpointer proc)
+{
+    rb_funcall((VALUE)proc, id_call, 0);
+    return Qnil;
+}
+
+static void
+gtk_m_function2(gpointer proc)
+{
+    G_PROTECT_CALLBACK(gtk_m_function2_body, proc);
+}
+
+
 static VALUE
 gtk_m_set_locale(self)
     VALUE self;
@@ -51,6 +88,8 @@ gtk_m_get_default_language(self)
 
 typedef void (*SignalFunc) (int);
 
+static gboolean _initialized = FALSE;
+
 static VALUE
 gtk_m_init(argc, argv, self)
     int argc;
@@ -61,6 +100,11 @@ gtk_m_init(argc, argv, self)
     VALUE argary;
     gchar** gargv;
 
+    if (_initialized)
+        return self;
+    else
+        _initialized = TRUE;
+
     rb_scan_args(argc, argv, "01", &argary);
 
     if (NIL_P(argary)){
@@ -86,7 +130,7 @@ gtk_m_init(argc, argv, self)
 
     {
         gboolean is_initialized;
-
+        GError* error = NULL;
         /* Gdk modifies sighandlers, sigh */
 #ifdef NT
         RETSIGTYPE (*sigfunc[3])();
@@ -107,7 +151,25 @@ gtk_m_init(argc, argv, self)
         sigfunc[5] = signal(SIGPIPE, SIG_IGN);
         sigfunc[6] = signal(SIGTERM, SIG_IGN);
 #endif
+
+#if GTK_CHECK_VERSION(2,6,0)
+        is_initialized = gtk_init_with_args(&gargc, &gargv, NULL, NULL, NULL, &error);
+#else
         is_initialized = gtk_init_check(&gargc, &gargv);
+#endif
+        if (! is_initialized) {
+            if (error){
+                rb_raise(rb_eRuntimeError, "%s", error->message);
+                g_error_free (error);
+            } else {
+                const char *display_name_arg = gdk_get_display_arg_name();
+                display_name_arg = display_name_arg ? display_name_arg : g_getenv("DISPLAY");
+                rb_raise(rb_eRuntimeError, "Cannot open display: %s", 
+                         display_name_arg ? display_name_arg : " ");
+            }
+
+        }
+
         setlocale(LC_NUMERIC, "C");
 
 #ifdef NT
@@ -123,9 +185,6 @@ gtk_m_init(argc, argv, self)
         signal(SIGPIPE, sigfunc[5]);
         signal(SIGTERM, sigfunc[6]);
 #endif
-        
-        if (!is_initialized)
-            rb_raise(rb_eRuntimeError, "failed to initialize gtk+");
     }
 
     return self;
@@ -136,14 +195,6 @@ gtk_init()
 gtk_exit()
 */
 
-static VALUE
-gtk_m_events_pending(self)
-    VALUE self;
-{
-    return gtk_events_pending() ? Qtrue : Qfalse;
-}
-
-
 /* 
  * An empty timeout 
  */
@@ -244,8 +295,8 @@ gtk_m_init_add(self)
     VALUE self;
 {
     volatile VALUE func = G_BLOCK_PROC();
-    
-    gtk_init_add((GtkFunction)gtk_m_function, (gpointer)func);
+
+    gtk_init_add((GtkFunction)gtk_m_function2, (gpointer)func);
     G_RELATIVE(self, func);
     return Qnil;
 }
@@ -255,12 +306,19 @@ gtk_m_quit_add(self, main_level)
     VALUE self, main_level;
 {
     volatile VALUE func = G_BLOCK_PROC();
-    VALUE id;
+    VALUE rb_id;
+    callback_info_t *info;
+    guint id;
 
-    id = INT2FIX(gtk_quit_add(NUM2UINT(main_level), 
-                                (GtkFunction)gtk_m_function, (gpointer)func));
-    G_RELATIVE2(self, func, id_relative_callbacks, id);
-    return id;
+    info = ALLOC(callback_info_t);
+    info->callback = func;
+    info->key = id_relative_callbacks;
+    id = gtk_quit_add_full(NUM2UINT(main_level), (GtkFunction)gtk_m_function,
+                           NULL, (gpointer)info, g_free);
+    info->id = id;
+    rb_id = UINT2NUM(id);
+    G_RELATIVE2(self, func, id__quit_callbacks__, rb_id);
+    return rb_id;
 }
 
 static VALUE
@@ -268,7 +326,7 @@ gtk_m_quit_remove(self, quit_handler_id)
     VALUE self, quit_handler_id;
 {
     gtk_quit_remove(NUM2UINT(quit_handler_id));
-    G_REMOVE_RELATIVE(self, id_relative_callbacks, quit_handler_id);
+    G_REMOVE_RELATIVE(self, id__quit_callbacks__, quit_handler_id);
     return quit_handler_id;
 }
 
@@ -283,23 +341,28 @@ static VALUE
 timeout_add(self, interval)
     VALUE self, interval;
 {
-    VALUE id;
-    VALUE func;
+    VALUE func, rb_id;
+    callback_info_t *info;
+    guint id;
 
     func = G_BLOCK_PROC();
-    id = INT2FIX(gtk_timeout_add(NUM2INT(interval),
-                                 (GtkFunction)gtk_m_function,
-                                 (gpointer)func));
-    G_RELATIVE2(self, func, id_relative_callbacks, id);
-    return id;
+    info = ALLOC(callback_info_t);
+    info->callback = func;
+    info->key = id__timeout_callbacks__;
+    id = gtk_timeout_add_full(NUM2UINT(interval), (GtkFunction)gtk_m_function,
+                              NULL, (gpointer)info, g_free);
+    info->id = id;
+    rb_id = UINT2NUM(id);
+    G_RELATIVE2(self, func, id__timeout_callbacks__, rb_id);
+    return rb_id;
 }
 
 static VALUE
 timeout_remove(self, id)
     VALUE self, id;
 {
-    gtk_timeout_remove(NUM2INT(id));
-    G_REMOVE_RELATIVE(self, id_relative_callbacks, id);
+    gtk_timeout_remove(NUM2UINT(id));
+    G_REMOVE_RELATIVE(self, id__timeout_callbacks__, id);
     return Qnil;
 }
 
@@ -307,36 +370,49 @@ static VALUE
 idle_add(self)
     VALUE self;
 {
-    VALUE id;
-    VALUE func;
+    VALUE func, rb_id;
+    callback_info_t *info;
+    guint id;
 
     func = G_BLOCK_PROC();
-    id = INT2FIX(gtk_idle_add((GtkFunction)gtk_m_function, (gpointer)func));
-    G_RELATIVE2(self, func, id_relative_callbacks, id);
-    return id;
+    info = ALLOC(callback_info_t);
+    info->callback = func;
+    info->key = id__idle_callbacks__;
+    id = gtk_idle_add_full(G_PRIORITY_DEFAULT_IDLE,
+                           (GtkFunction)gtk_m_function, NULL,
+                           (gpointer)info, g_free);
+    info->id = id;
+    rb_id = UINT2NUM(id);
+    G_RELATIVE2(self, func, id__idle_callbacks__, rb_id);
+    return rb_id;
 }
 
 static VALUE
 idle_add_priority(self, priority)
     VALUE self;
 {
-    VALUE id;
-    VALUE func;
+    VALUE func, rb_id;
+    callback_info_t *info;
+    guint id;
 
     func = G_BLOCK_PROC();
-    id = INT2FIX(gtk_idle_add_priority(NUM2INT(priority),
-                                       (GtkFunction)gtk_m_function, 
-                                       (gpointer)func));
-    G_RELATIVE2(self, func, id_relative_callbacks, id);
-    return id;
+    info = ALLOC(callback_info_t);
+    info->callback = func;
+    info->key = id__idle_callbacks__;
+    id = gtk_idle_add_full(NUM2INT(priority), (GtkFunction)gtk_m_function,
+                           NULL, (gpointer)info, g_free);
+    info->id = id;
+    rb_id = UINT2NUM(id);
+    G_RELATIVE2(self, func, id__idle_callbacks__, rb_id);
+    return rb_id;
 }
 
 static VALUE
 idle_remove(self, id)
     VALUE self, id;
 {
-    gtk_idle_remove(NUM2INT(id));
-    G_REMOVE_RELATIVE(self, id_relative_callbacks, id);
+    gtk_idle_remove(NUM2UINT(id));
+    G_REMOVE_RELATIVE(self, id__idle_callbacks__, id);
     return Qnil;
 }
 
@@ -369,7 +445,7 @@ gtk_m_key_snooper_install(self)
     VALUE id = INT2FIX(gtk_key_snooper_install(
                            (GtkKeySnoopFunc)gtk_m_key_snoop_func, 
                            (gpointer)func));
-    G_RELATIVE2(self, func, id_relative_callbacks, id);
+    G_RELATIVE2(self, func, id__snooper_callbacks__, id);
     return id;
 }
 
@@ -378,7 +454,7 @@ gtk_m_key_snooper_remove(self, id)
     VALUE self, id;
 {
     gtk_key_snooper_remove(NUM2UINT(id));
-    G_REMOVE_RELATIVE(self, id_relative_callbacks, id);
+    G_REMOVE_RELATIVE(self, id__snooper_callbacks__, id);
     return Qnil;
 }
 
@@ -450,7 +526,11 @@ gtk_m_check_version_q(self, major, minor, micro)
 void 
 Init_gtk_main()
 {
-    rb_define_module_function(mGtk, "events_pending?", gtk_m_events_pending, 0);
+    id__quit_callbacks__ = rb_intern("__quit_callbacks__");
+    id__timeout_callbacks__ = rb_intern("__timeout_callbacks__");
+    id__idle_callbacks__ = rb_intern("__idle_callbacks__");
+    id__snooper_callbacks__ = rb_intern("__snooper_callbacks__");
+
     rb_define_module_function(mGtk, "set_locale", gtk_m_set_locale, 0);
     rb_define_module_function(mGtk, "disable_setlocale", gtk_m_disable_setlocale, 0);
     rb_define_module_function(mGtk, "default_language", gtk_m_get_default_language, 0);
