@@ -4,8 +4,9 @@
   rbgtktextiter.c -
 
   $Author: mutoh $
-  $Date: 2005/02/12 16:03:46 $
+  $Date: 2006/06/17 06:59:32 $
 
+  Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
   Copyright (C) 2002,2003 Masahiro Sakai
 ************************************************/
 
@@ -16,6 +17,7 @@
 #define ITR2RVAL(i) (BOXED2RVAL(i, GTK_TYPE_TEXT_ITER))
 
 static gboolean is_compat_240;
+static ID id_pixbuf;
 
 static VALUE
 get_buffer(self)
@@ -82,21 +84,26 @@ get_pixbuf(self)
     VALUE self;
 {
     GdkPixbuf* pixbuf = gtk_text_iter_get_pixbuf(_SELF(self));
-    return pixbuf ? GOBJ2RVAL(pixbuf) : Qnil;
+    VALUE ret = Qnil;
+    if (pixbuf){
+        ret = GOBJ2RVAL(pixbuf);
+        G_CHILD_SET(self, id_pixbuf, ret);
+    }
+    return Qnil;
 }
 
 static VALUE
 get_marks(self)
     VALUE self;
 {
-    return GSLIST2ARY(gtk_text_iter_get_marks(_SELF(self)));
+    return GSLIST2ARYF(gtk_text_iter_get_marks(_SELF(self)));
 }
 
 static VALUE
 get_toggled_tags(self, toggled_on)
     VALUE self, toggled_on;
 {
-    return GSLIST2ARY(gtk_text_iter_get_toggled_tags(_SELF(self), RTEST(toggled_on)));
+    return GSLIST2ARYF(gtk_text_iter_get_toggled_tags(_SELF(self), RTEST(toggled_on)));
 }
 
 static VALUE
@@ -111,51 +118,49 @@ static VALUE
 begins_tag(self, tag)
     VALUE self, tag;
 {
-    return gtk_text_iter_begins_tag(_SELF(self), RVAL2TAG(tag)) ? Qtrue : Qfalse;
+    return CBOOL2RVAL(gtk_text_iter_begins_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
 ends_tag(self, tag)
     VALUE self, tag;
 {
-    return gtk_text_iter_ends_tag(_SELF(self), RVAL2TAG(tag)) ? Qtrue : Qfalse;
+    return CBOOL2RVAL(gtk_text_iter_ends_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
 toggles_tag(self, tag)
     VALUE self, tag;
 {
-    return gtk_text_iter_toggles_tag(_SELF(self), RVAL2TAG(tag)) ? Qtrue : Qfalse;
+    return CBOOL2RVAL(gtk_text_iter_toggles_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
 has_tag(self, tag)
     VALUE self, tag;
 {
-    return gtk_text_iter_has_tag(_SELF(self), RVAL2TAG(tag)) ? Qtrue : Qfalse;
+    return CBOOL2RVAL(gtk_text_iter_has_tag(_SELF(self), RVAL2TAG(tag)));
 }
 
 static VALUE
 get_tags(self)
     VALUE self;
 {
-    return GSLIST2ARY(gtk_text_iter_get_tags(_SELF(self)));
+    return GSLIST2ARYF(gtk_text_iter_get_tags(_SELF(self)));
 }
 
 static VALUE
 editable(self, default_setting)
     VALUE self, default_setting;
 {
-    return gtk_text_iter_editable(_SELF(self), RTEST(default_setting))
-        ? Qtrue : Qfalse;
+    return CBOOL2RVAL(gtk_text_iter_editable(_SELF(self), RTEST(default_setting)));
 }
 
 static VALUE
 can_insert(self, default_setting)
     VALUE self, default_setting;
 {
-    return gtk_text_iter_can_insert(_SELF(self), RTEST(default_setting))
-        ? Qtrue : Qfalse;
+    return CBOOL2RVAL(gtk_text_iter_can_insert(_SELF(self), RTEST(default_setting)));
 }
 
     
@@ -164,7 +169,7 @@ static VALUE \
 __name__(self) \
     VALUE self; \
 { \
-    return gtk_text_iter_##__name__(_SELF(self)) ? Qtrue : Qfalse; \
+    return CBOOL2RVAL(gtk_text_iter_##__name__(_SELF(self)));   \
 }
 
 def_predicate(starts_word)
@@ -246,6 +251,12 @@ def_move(backward_visible_cursor_position)
 def_move_gint(forward_visible_cursor_positions)
 def_move_gint(backward_visible_cursor_positions)
 #endif
+#if GTK_CHECK_VERSION(2,8,0)
+def_move(forward_visible_line)
+def_move(backward_visible_line)
+def_move_gint(forward_visible_lines)
+def_move_gint(backward_visible_lines)
+#endif
 def_move(forward_cursor_position)
 def_move(backward_cursor_position)
 def_move_gint(forward_cursor_positions)
@@ -431,6 +442,8 @@ Init_gtk_textiter()
 
     is_compat_240 = gtk_check_version(2, 4, 0) ? FALSE : TRUE;
 
+    id_pixbuf = rb_intern("pixbuf");
+
     rb_define_method(cTextIter, "buffer", get_buffer, 0);
     rb_define_method(cTextIter, "offset", get_offset, 0);
     rb_define_method(cTextIter, "line", get_line, 0);
@@ -503,6 +516,12 @@ Init_gtk_textiter()
     rb_define_method(cTextIter, "backward_visible_cursor_position", backward_visible_cursor_position, 0);
     rb_define_method(cTextIter, "forward_visible_cursor_positions", forward_visible_cursor_positions, 1);
     rb_define_method(cTextIter, "backward_visible_cursor_positions", backward_visible_cursor_positions, 1); 
+#endif
+#if GTK_CHECK_VERSION(2,8,0)
+    rb_define_method(cTextIter, "forward_visible_line", forward_visible_line, 0); 
+    rb_define_method(cTextIter, "backward_visible_line", backward_visible_line, 0); 
+    rb_define_method(cTextIter, "forward_visible_lines", forward_visible_lines, 1); 
+    rb_define_method(cTextIter, "backward_visible_lines", backward_visible_lines, 1); 
 #endif
     rb_define_method(cTextIter, "forward_cursor_position", forward_cursor_position, 0);
     rb_define_method(cTextIter, "backward_cursor_position", backward_cursor_position, 0);
