@@ -4,7 +4,7 @@
   rbgtktreeviewcolumn.c -
 
   $Author: mutoh $
-  $Date: 2005/01/29 11:44:15 $
+  $Date: 2006/06/17 06:59:32 $
 
   Copyright (C) 2002-2004 Masao Mutoh
 ************************************************/
@@ -30,8 +30,10 @@ tvc_initialize(argc, argv, self)
     tvc = gtk_tree_view_column_new();
     if (argc > 0){
         gtk_tree_view_column_set_title(tvc, RVAL2CSTR(argv[0]));
-        if (argc > 1)
+        if (argc > 1) {
             gtk_tree_view_column_pack_start(tvc, RVAL2CELLRENDERER(argv[1]), TRUE);
+            G_CHILD_ADD(self, argv[1]);
+        }
     }
 
     RBGTK_INITIALIZE(self, tvc);
@@ -58,6 +60,7 @@ static VALUE
 tvc_pack_start(self, cell, expand)
     VALUE self, cell, expand;
 {
+    G_CHILD_ADD(self, cell);
     gtk_tree_view_column_pack_start(_SELF(self), RVAL2CELLRENDERER(cell), RTEST(expand));
     return self;
 }
@@ -66,6 +69,7 @@ static VALUE
 tvc_pack_end(self, cell, expand)
     VALUE self, cell, expand;
 {
+    G_CHILD_ADD(self, cell);
     gtk_tree_view_column_pack_end(_SELF(self), RVAL2CELLRENDERER(cell), RTEST(expand));
     return self;
 }
@@ -74,6 +78,7 @@ static VALUE
 tvc_clear(self)
     VALUE self;
 {
+    G_CHILD_REMOVE_ALL(self);
     gtk_tree_view_column_clear(_SELF(self));
     return self;
 }
@@ -82,7 +87,7 @@ static VALUE
 tvc_get_cell_renderers(self)
     VALUE self;
 {
-    return GLIST2ARY(gtk_tree_view_column_get_cell_renderers(_SELF(self)));
+    return GLIST2ARYF(gtk_tree_view_column_get_cell_renderers(_SELF(self)));
 }
 
 static VALUE
@@ -265,6 +270,17 @@ tvc_focus_cell(self, renderer)
 
 #endif
 
+#if GTK_CHECK_VERSION(2,8,0)
+static VALUE
+tvc_queue_resize(self)
+    VALUE self;
+{
+    gtk_tree_view_column_queue_resize(_SELF(self));
+    return self;
+}
+#endif
+
+
 void
 Init_gtk_treeviewcolumn()
 {
@@ -285,10 +301,13 @@ Init_gtk_treeviewcolumn()
     rb_define_method(tvc, "set_sort_column_id", tvc_set_sort_column_id, 1);
     rb_define_method(tvc, "sort_column_id", tvc_get_sort_column_id, 0);
     rb_define_method(tvc, "cell_set_cell_data", tvc_cell_set_cell_data, 4);
-    rb_define_method(tvc, "cell_size", tvc_cell_get_size, -1);
+    rb_define_method(tvc, "cell_size", tvc_cell_get_size, 0);
     rb_define_method(tvc, "cell_is_visible?", tvc_cell_is_visible, 0);
 #if GTK_CHECK_VERSION(2,2,0)
     rb_define_method(tvc, "focus_cell", tvc_focus_cell, 1);
+#endif
+#if GTK_CHECK_VERSION(2,8,0)
+    rb_define_method(tvc, "queue_resize", tvc_queue_resize, 0);
 #endif
     /* GtkTreeViewColumnSizing */
     G_DEF_CLASS(GTK_TYPE_TREE_VIEW_COLUMN_SIZING, "Sizing", tvc);
