@@ -3,10 +3,10 @@
 
   rbgtkwidget.c -
 
-  $Author: ktou $
-  $Date: 2005/07/30 03:25:02 $
+  $Author: mutoh $
+  $Date: 2006/06/17 06:59:32 $
 
-  Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
+  Copyright (C) 2002-2006 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
                           Daisuke Kanda,
                           Hiroshi Igarashi
@@ -215,7 +215,7 @@ static VALUE
 widget_list_accel_closures(self)
     VALUE self;
 {
-    return GLIST2ARY2(gtk_widget_list_accel_closures(_SELF(self)), G_TYPE_CLOSURE);
+    return GLIST2ARY2F(gtk_widget_list_accel_closures(_SELF(self)), G_TYPE_CLOSURE);
 }
 
 #if GTK_CHECK_VERSION(2,4,0)
@@ -340,7 +340,7 @@ static VALUE
 widget_set_colormap(self, colormap)
     VALUE self, colormap;
 {
-    gtk_widget_set_colormap(_SELF(self), GDK_COLORMAP(RVAL2GOBJ(self)));
+    gtk_widget_set_colormap(_SELF(self), GDK_COLORMAP(RVAL2GOBJ(colormap)));
     return self;
 }
 
@@ -624,11 +624,16 @@ widget_create_pango_layout(argc, argv, self)
 }
 
 static VALUE
-widget_render_icon(self, stock_id, size, detail)
-    VALUE self, stock_id, size, detail;
+widget_render_icon(argc, argv, self)
+    int argc;
+    VALUE* argv;
+    VALUE self;
 {
-    return GOBJ2RVAL(gtk_widget_render_icon(_SELF(self),  rb_id2name(SYM2ID(stock_id)),
-                                            RVAL2GENUM(size, GTK_TYPE_ICON_SIZE), RVAL2CSTR(detail)));
+    VALUE stock_id, size, detail;
+    rb_scan_args(argc, argv, "21", &stock_id, &size, &detail);
+    return GOBJ2RVAL(gtk_widget_render_icon(_SELF(self), rb_id2name(SYM2ID(stock_id)),
+                                            RVAL2GENUM(size, GTK_TYPE_ICON_SIZE),
+                                            NIL_P(detail) ? NULL : RVAL2CSTR(detail)));
 }
 
 static VALUE
@@ -1008,10 +1013,7 @@ static VALUE
 widget_list_mnemonic_labels(self)
     VALUE self;
 {
-    GList* list = gtk_widget_list_mnemonic_labels(_SELF(self));
-    VALUE ret = GLIST2ARY(list);
-    g_list_free(list);
-    return ret;
+    return GLIST2ARYF(gtk_widget_list_mnemonic_labels(_SELF(self)));
 }
 
 static VALUE
@@ -1039,6 +1041,14 @@ widget_window(self)
     return window ? GOBJ2RVAL(window) : Qnil;
 }
 
+static VALUE
+widget_set_window(self, window)
+    VALUE self;
+{
+    _SELF(self)->window = RVAL2GOBJ(window);
+    return self;
+}
+
 #define DEFINE_IS_WIDGET(STATE) \
 static VALUE \
 widget_ ## STATE (self) \
@@ -1085,6 +1095,16 @@ widget_get_requisition(self)
     return rb_ary_new3(2, INT2NUM(req.width), INT2NUM(req.height));
 }
 
+static VALUE
+widget_set_requisition(self, w, h)
+    VALUE self, w, h;
+{
+    GtkRequisition *r = &(_SELF(self)->requisition);
+    r->width  = NUM2INT(w);
+    r->height = NUM2INT(h);
+    return self;    
+}
+
 static VALUE
 widget_state(self)
     VALUE self;
@@ -1116,6 +1136,7 @@ widget_signal_size_allocate(num, values)
     GtkAllocation* alloc = (GtkAllocation*)g_value_get_boxed(&values[1]);
     return rb_ary_new3(2, GVAL2RVAL(&values[0]), BOXED2RVAL(alloc, GTK_TYPE_ALLOCATION));
 }
+
 void 
 Init_gtk_widget()
 {
@@ -1198,7 +1219,7 @@ Init_gtk_widget()
     rb_define_method(gWidget, "create_pango_context", widget_create_pango_context, 0);
     rb_define_method(gWidget, "pango_context", widget_get_pango_context, 0);
     rb_define_method(gWidget, "create_pango_layout", widget_create_pango_layout, -1);
-    rb_define_method(gWidget, "render_icon", widget_render_icon, 3);
+    rb_define_method(gWidget, "render_icon", widget_render_icon, -1);
     rb_define_method(gWidget, "queue_draw_area", widget_queue_draw_area, 4);
     rb_define_method(gWidget, "reset_shapes", widget_reset_shapes, 0);
     rb_define_method(gWidget, "set_double_buffered", widget_set_double_buffered, 1);
@@ -1234,9 +1255,11 @@ Init_gtk_widget()
     rb_define_method(gWidget, "remove_mnemonic_label", widget_remove_mnemonic_label, 1);
 #endif
     rb_define_method(gWidget, "window", widget_window, 0);
+    rb_define_method(gWidget, "set_window", widget_set_window, 1);
     rb_define_method(gWidget, "allocation", widget_get_allocation, 0);
     rb_define_method(gWidget, "set_allocation", widget_set_allocation, 4);
     rb_define_method(gWidget, "requisition", widget_get_requisition, 0);
+    rb_define_method(gWidget, "set_requisition", widget_set_requisition, 2);
     rb_define_method(gWidget, "state", widget_state, 0);
     rb_define_method(gWidget, "saved_state", widget_saved_state, 0);
 
