@@ -4,9 +4,9 @@
   rbgtkwindow.c -
 
   $Author: mutoh $
-  $Date: 2005/07/14 17:01:50 $
+  $Date: 2006/06/17 06:59:32 $
 
-  Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
+  Copyright (C) 2002-2006 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
                           Daisuke Kanda,
                           Hiroshi Igarashi
@@ -76,14 +76,30 @@ static VALUE
 gwin_activate_focus(self)
     VALUE self;
 {
-    gtk_window_activate_focus(_SELF(self));
-    return self;
+    return CBOOL2RVAL(gtk_window_activate_focus(_SELF(self)));
 }
 
 static VALUE
 gwin_activate_default(self)
     VALUE self;
 {
+    return CBOOL2RVAL(gtk_window_activate_default(_SELF(self)));
+}
+
+static VALUE
+gwin_active_focus(self)
+    VALUE self;
+{
+    rb_warning("Gtk::Window#active_focus is deprecated. Use Gtk::Window#activate_focus");
+    gtk_window_activate_focus(_SELF(self));
+    return self;
+}
+
+static VALUE
+gwin_active_default(self)
+    VALUE self;
+{
+    rb_warning("Gtk::Window#active_default is deprecated. Use Gtk::Window#activate_default");
     gtk_window_activate_default(_SELF(self));
     return self;
 }
@@ -151,7 +167,11 @@ static VALUE
 gwin_s_list_toplevels(self)
     VALUE self;
 {
-    return GLIST2ARY(gtk_window_list_toplevels());
+    GList* list = gtk_window_list_toplevels();
+    VALUE ret = GLIST2ARY(list);
+    g_list_foreach(list, (GFunc)g_object_ref, NULL);
+    g_list_free(list);
+    return ret;
 }
 
 static VALUE
@@ -204,6 +224,22 @@ gwin_set_default(self, win)
     return self;
 }
 
+#if GTK_CHECK_VERSION(2,8,0)
+static VALUE
+gwin_present(argc, argv, self)
+    int argc;
+    VALUE *argv;
+    VALUE self;
+{
+    VALUE timestamp;
+    if (rb_scan_args(argc, argv, "01", &timestamp) == 1) {
+        gtk_window_present_with_time(_SELF(self), NUM2UINT(timestamp));
+    } else {
+        gtk_window_present(_SELF(self));
+    }
+    return self;
+}
+#else
 static VALUE
 gwin_present(self)
     VALUE self;
@@ -211,6 +247,7 @@ gwin_present(self)
     gtk_window_present(_SELF(self));
     return self;
 }
+#endif
 
 static VALUE
 gwin_iconify(self)
@@ -379,6 +416,9 @@ void        gtk_window_set_icon_name        (GtkWindow *window,
 void        gtk_window_set_focus_on_map     (GtkWindow *window,
                                              gboolean setting);
 gboolean    gtk_window_get_focus_on_map     (GtkWindow *window);
+
+void        gtk_window_set_urgency_hint     (GtkWindow *window,
+                                             gboolean setting);
 */
 
 
@@ -393,7 +433,7 @@ static VALUE
 gwin_s_get_default_icon_list(self)
     VALUE self;
 {
-    return GLIST2ARY(gtk_window_get_default_icon_list());
+    return GLIST2ARYF(gtk_window_get_default_icon_list());
 }
 
 static VALUE
@@ -435,7 +475,7 @@ static VALUE
 gwin_get_icon_list(self)
     VALUE self;
 {
-    return GLIST2ARY(gtk_window_get_icon_list(_SELF(self)));
+    return GLIST2ARYF(gtk_window_get_icon_list(_SELF(self)));
 }
 
 static VALUE
@@ -645,6 +685,16 @@ gwin_decorated_window_move_resize_window(self)
 }
 */
 
+static void
+mark_toplevels(void* _)
+{
+    GList* list = gtk_window_list_toplevels();
+    GList* p;
+    for (p = list; p; p = g_list_next(p))
+        rbgobj_gc_mark_instance(p->data);
+    g_list_free(list);
+}
+
 void 
 Init_gtk_window()
 {
@@ -654,8 +704,11 @@ Init_gtk_window()
     rb_define_method(gWindow, "set_wmclass", gwin_set_wmclass, 2);
     rb_define_method(gWindow, "add_accel_group", gwin_add_accel_group, 1);
     rb_define_method(gWindow, "remove_accel_group", gwin_remove_accel_group, 1);
-    rb_define_method(gWindow, "active_focus", gwin_activate_focus, 0);
-    rb_define_method(gWindow, "active_default", gwin_activate_default, 0);
+    /* active_(focus|default) are deprecated. Use activate_* instead. */
+    rb_define_method(gWindow, "active_focus", gwin_active_focus, 0);
+    rb_define_method(gWindow, "active_default", gwin_active_default, 0);
+    rb_define_method(gWindow, "activate_focus", gwin_activate_focus, 0);
+    rb_define_method(gWindow, "activate_default", gwin_activate_default, 0);
     rb_define_method(gWindow, "set_default_size", gwin_set_default_size, 2);
     rb_define_method(gWindow, "set_geometry_hints", gwin_set_geometry_hints, 3);
     rb_define_method(gWindow, "set_gravity", gwin_set_gravity, 1);
@@ -669,7 +722,11 @@ Init_gtk_window()
     rb_define_method(gWindow, "focus", gwin_get_focus, 0);
     rb_define_method(gWindow, "set_focus", gwin_set_focus, 1);
     rb_define_method(gWindow, "set_default", gwin_set_default, 1);
+#if GTK_CHECK_VERSION(2,8,0)
+    rb_define_method(gWindow, "present", gwin_present, -1);
+#else
     rb_define_method(gWindow, "present", gwin_present, 0);
+#endif
     rb_define_method(gWindow, "iconify", gwin_iconify, 0);
     rb_define_method(gWindow, "deiconify", gwin_deiconify, 0);
     rb_define_method(gWindow, "stick", gwin_stick, 0);
@@ -738,4 +795,11 @@ Init_gtk_window()
     /* GtkWindowType (from General constants) */
     G_DEF_CLASS(GTK_TYPE_WINDOW_TYPE, "Type", gWindow);
     G_DEF_CONSTANTS(gWindow, GTK_TYPE_WINDOW_TYPE, "GTK_WINDOW_");
+
+    {
+        static VALUE toplevels_marker;
+        toplevels_marker =
+            rb_data_object_alloc(rb_cData, NULL, mark_toplevels, NULL);
+        rb_global_variable(&toplevels_marker);
+    }
 }
