@@ -4,9 +4,9 @@
   rbgtksourcemain.c -
 
   $Author $
-  $Date: 2004/08/05 18:13:49 $
+  $Date: 2005/10/07 19:26:15 $
 
-  Copyright (C) 2004 Ruby-GNOME2 Project Team
+  Copyright (C) 2004,2005 Ruby-GNOME2 Project Team
   Copyright (C) 2003 Geoff Youngs, based on gtktextview.c by Masao Mutoh
 ************************************************/
 #include "rbgtksourcemain.h"
@@ -20,17 +20,21 @@ extern void Init_gtk_sourcelanguagesmanager (void);
 extern void Init_gtk_sourcemarker (void);
 extern void Init_gtk_sourcebuffer (void);
 extern void Init_gtk_sourceiter (void);
+extern void Init_gtk_sourcestylescheme (void);
+extern void Init_gtk_sourceprintjob (void);
 
 void
 Init_gtksourceview (void)
 {
-	Init_gtk_sourceview ();
-	Init_gtk_sourcetag ();
-	Init_gtk_sourcetagstyle ();
-	Init_gtk_sourcetagtable ();
-	Init_gtk_sourcelanguage ();
-	Init_gtk_sourcelanguagesmanager ();
-	Init_gtk_sourcemarker ();
-	Init_gtk_sourcebuffer ();
-	Init_gtk_sourceiter ();
+    Init_gtk_sourceview ();
+    Init_gtk_sourcetag ();
+    Init_gtk_sourcetagstyle ();
+    Init_gtk_sourcetagtable ();
+    Init_gtk_sourcelanguage ();
+    Init_gtk_sourcelanguagesmanager ();
+    Init_gtk_sourcemarker ();
+    Init_gtk_sourcebuffer ();
+    Init_gtk_sourceiter ();
+    Init_gtk_sourcestylescheme ();
+    Init_gtk_sourceprintjob ();
 }
