@@ -4,7 +4,7 @@
   rbglade.c -
 
   $Author: mutoh $
-  $Date: 2005/02/12 04:10:51 $
+  $Date: 2006/06/17 07:42:50 $
 
 
   Copyright (C) 2002-2005 Ruby-GNOME2 Project
@@ -22,6 +22,8 @@
 #include <gtk/gtk.h>
 #include <gmodule.h>
 
+#include "rblibgladeversion.h"
+
 #ifdef HAVE_LIBINTL_H
 #include <libintl.h>
 #endif
@@ -41,10 +43,29 @@ rb_gladexml_get_tooltips(VALUE self, VALUE toplevel)
 static VALUE
 rb_gladexml_get_widget(VALUE self, VALUE nameString)
 {
-    GtkWidget *widget = glade_xml_get_widget(GLADE_XML(RVAL2GOBJ(self)), STR2CSTR(nameString));
+    GtkWidget *widget = glade_xml_get_widget(GLADE_XML(RVAL2GOBJ(self)), RVAL2CSTR(nameString));
     return widget ? GOBJ2RVAL(widget) : Qnil;
 }
 
+static VALUE
+rb_gladexml_get_widget_prefix(VALUE self, VALUE name)
+{
+    GList* list = glade_xml_get_widget_prefix(GLADE_XML(RVAL2GOBJ(self)), RVAL2CSTR(name));
+    return GLIST2ARYF(list);
+}
+
+static VALUE
+rb_gladexml_s_get_widget_name(VALUE self, VALUE widget)
+{
+    return CSTR2RVAL(glade_get_widget_name(RVAL2GOBJ(widget)));
+}
+
+static VALUE
+rb_gladexml_s_get_widget_tree(VALUE self, VALUE widget)
+{
+    return GOBJ2RVAL(glade_get_widget_tree(RVAL2GOBJ(widget)));
+}
+
 static void
 xml_autoconnect(const gchar *handler_name, GObject *_source,
                 const gchar *signal_name, const gchar *signal_data,
@@ -121,6 +142,11 @@ rb_gladexml_initialize(int argc, VALUE *argv, VALUE self)
 #ifdef HAVE_BINDTEXTDOMAIN
     if (localedir){
         bindtextdomain(domain, localedir);
+    } else {
+        const gchar* env = g_getenv("GETTEXT_PATH");
+        if (env){
+            bindtextdomain(domain, env);
+        }
     }
     if (domain){
 #ifdef HAVE_BIND_TEXTDOMAIN_CODESET
@@ -241,16 +267,27 @@ void
 Init_libglade2()
 {
     cGladeXML = G_DEF_CLASS(GLADE_TYPE_XML, "GladeXML", rb_cObject);
+
     rb_define_method(cGladeXML, "signal_autoconnect_full", rb_gladexml_signal_autoconnect_full, 0);
     rb_define_method(cGladeXML, "initialize", rb_gladexml_initialize, -1);
     rb_define_method(cGladeXML, "get_tooltips", rb_gladexml_get_tooltips, 1);
     rb_define_method(cGladeXML, "get_widget", rb_gladexml_get_widget, 1);
     rb_define_alias(cGladeXML, "[]", "get_widget");
+    rb_define_method(cGladeXML, "get_widget_prefix", rb_gladexml_get_widget_prefix, 1);
+    rb_define_singleton_method(cGladeXML, "get_widget_name", rb_gladexml_s_get_widget_name, 1);
+    rb_define_singleton_method(cGladeXML, "get_widget_tree", rb_gladexml_s_get_widget_tree, 1);
     rb_define_method(cGladeXML, "filename"  , rb_gladexml_filename, 0);
     rb_define_singleton_method(cGladeXML, "set_custom_widget_handler", rb_gladexml_set_custom_widget_handler, 1);
     rb_define_singleton_method(cGladeXML, "require", rb_gladexml_require, 1);
     rb_define_singleton_method(cGladeXML, "provide", rb_gladexml_provide, 1);
+
     rb_define_const(cGladeXML, "FILE", INT2FIX(RB_GLADE_XML_FILE));
     rb_define_const(cGladeXML, "BUFFER", INT2FIX(RB_GLADE_XML_BUFFER));
 
+    rb_define_const(cGladeXML, "BUILD_VERSION",
+                    rb_ary_new3(3,
+                                INT2FIX(LIBGLADE_MAJOR_VERSION),
+                                INT2FIX(LIBGLADE_MINOR_VERSION),
+                                INT2FIX(LIBGLADE_MICRO_VERSION)));
+
 }
