@@ -1,10 +1,10 @@
 =begin
   test.rb - Ruby/Libglade2 sample script.
 
-  Copyright (c) 2002,2003 Ruby-GNOME2 Project
+  Copyright (c) 2002-2006 Ruby-GNOME2 Project
   This program is licenced under the same licence as Ruby-GNOME2.
 
-  $Id: test.rb,v 1.6 2005/09/19 14:05:21 mutoh Exp $
+  $Id: test.rb,v 1.8 2006/06/17 14:14:55 mutoh Exp $
 =end
 
 require 'libglade2'
@@ -13,7 +13,7 @@ class Test
   def initialize
     @glade = GladeXML.new("test.glade") {|handler| method(handler)}
     @entry = @glade["entrybox"]
-p @glade.get_widget_prefix("foo")
+    p @glade.get_widget_prefix("w")
   end
   
   def say_hello(widget)
@@ -25,6 +25,5 @@ p @glade.get_widget_prefix("foo")
   end
 end
 
-Gtk.init
 Test.new
 Gtk.main
