@@ -26,18 +26,26 @@ have_func("pango_attr_iterator_get_attrs")
 have_func("pango_itemize_with_base_dir")
 have_func("pango_font_family_is_monospace")
 
+PKGConfig.have_package('pangocairo')
+if have_header('rb_cairo.h')
+  if /mingw|cygwin|mswin32/ =~ RUBY_PLATFORM
+    unless ENV["CAIRO_PATH"]
+      puts "Error! Set CAIRO_PATH."
+      exit 1
+    end
+    add_depend_package("cairo", "packages/cairo/ext", ENV["CAIRO_PATH"])
+    $defs << "-DRUBY_CAIRO_PLATFORM_WIN32"
+  end
+end
+
 add_depend_package("glib2", "glib/src", TOPDIR)
 
 add_distcleanfile("rbpangoinits.c")
-add_distcleanfile("rbpangoversion.h")
+
+make_version_header("PANGO", "pango")
 
 create_makefile_at_srcdir(PACKAGE_NAME, SRCDIR, "-DRUBY_PANGO_COMPILATION") {
-  pango_version = PKGConfig.modversion(PACKAGE_NAME)
-
-  File.delete("rbpangoinits.c") if FileTest.exist?("rbpangoinits.c")
-  File.delete("rbpangoversion.h") if FileTest.exist?("rbpangoversion.h")
   system("ruby #{SRCDIR}/makeinits.rb #{SRCDIR}/*.c > rbpangoinits.c")
-  system("ruby #{SRCDIR}/makeversion.rb #{pango_version} > rbpangoversion.h")
 }
 
 create_top_makefile
