@@ -4,7 +4,7 @@
   rbpangofontmap.c -
 
   $Author: mutoh $
-  $Date: 2005/02/13 17:31:33 $
+  $Date: 2005/10/14 17:47:41 $
 
   Copyright (C) 2002-2005 Masao Mutoh
 ************************************************/
@@ -92,5 +92,10 @@ Init_pango_font_map()
 
     G_DEF_CLASS3("PangoFcFontMap", "FcFontMap", mPango);
     G_DEF_CLASS3("PangoXftFontMap", "XftFontMap", mPango);
+    G_DEF_CLASS3("PangoFT2FontMap", "FT2FontMap", mPango);
+    G_DEF_CLASS3("PangoXFontMap", "XFontMap", mPango);
+    G_DEF_CLASS3("PangoWin32FontMap", "Win32FontMap", mPango);
+    G_DEF_CLASS3("PangoCairoFcFontMap", "CairoFcFontMap", mPango);
+    G_DEF_CLASS3("PangoCairoWin32FontMap", "CairoWin32FontMap", mPango);
 }
 
