@@ -4,7 +4,7 @@
   rbpangomain.c -
 
   $Author: mutoh $
-  $Date: 2005/03/05 16:23:46 $
+  $Date: 2006/06/17 07:50:46 $
 
   Copyright (C) 2002-2005 Masao Mutoh
 ************************************************/
@@ -32,7 +32,7 @@ rpango_reorder_items(self, logical_items)
     ret = pango_reorder_items(glist);
     g_list_free(glist);
 
-    return ret ? GLIST2ARY2(ret, PANGO_TYPE_ITEM) : Qnil;
+    return GLIST2ARY2(ret, PANGO_TYPE_ITEM);
 }
 
 #if PANGO_CHECK_VERSION(1,4,0)
@@ -163,6 +163,8 @@ rpango_parse_markup(argc, argv, self)
 
     rb_scan_args(argc, argv, "11", &markup_text, &accel_marker);
 
+    if (NIL_P(markup_text)) rb_raise(rb_eRuntimeError, "1st argument can't accept nil");
+
     ret = pango_parse_markup(RVAL2CSTR(markup_text),
                              RSTRING(markup_text)->len,
                              NIL_P(accel_marker) ? 0 : NUM2CHR(accel_marker),
